"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QRandomGenerator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrandomgenerator.html

    **Detailed Description**

    QRandomGenerator may be used to generate random values from a high-quality
    random number generator. Like the C++ random engines, QRandomGenerator can
    be seeded with user-provided values through the constructor. When seeded,
    the sequence of numbers generated by this class is deterministic. That is to
    say, given the same seed data, QRandomGenerator will generate the same
    sequence of numbers. But given different seeds, the results should be
    considerably different.

    **QRandomGenerator::securelySeeded** () can be used to create a
    QRandomGenerator that is securely seeded with **QRandomGenerator::system**
    (), meaning that the sequence of numbers it generates cannot be easily
    predicted. Additionally, **QRandomGenerator::global** () returns a global
    instance of QRandomGenerator that Qt will ensure to be securely seeded. This
    object is thread-safe, may be shared for most uses, and is always seeded
    from **QRandomGenerator::system** ()

    **QRandomGenerator::system** () may be used to access the system's
    cryptographically-safe random generator. On Unix systems, it's equivalent to
    reading from `/dev/urandom` or the `getrandom()` or `getentropy()` system
    calls.

    The class can generate 32-bit or 64-bit quantities, or fill an array of
    those. The most common way of generating new values is to call the
    **generate** (), **generate64** () or **fillRange** () functions. One would
    use it as:

    **quint32**  value = **QRandomGenerator** ::global()->generate();

    Additionally, it provides a floating-point function **generateDouble** ()
    that returns a number in the range [0, 1) (that is, inclusive of zero and
    exclusive of 1). There's also a set of convenience functions that facilitate
    obtaining a random number in a bounded, integral range.

    **Seeding and determinism**

    QRandomGenerator may be seeded with specific seed data. When that is done,
    the numbers generated by the object will always be the same, as in the
    following example:

    **QRandomGenerator**  prng1(1234), prng2(1234);
    Q_ASSERT(prng1.generate() == prng2.generate());
    Q_ASSERT(prng1.generate64() == prng2.generate64());

    The seed data takes the form of one or more 32-bit words. The ideal seed
    size is approximately equal to the size of the QRandomGenerator class
    itself. Due to mixing of the seed data, QRandomGenerator cannot guarantee
    that distinct seeds will produce different sequences.

    **QRandomGenerator::global** (), like all generators created by
    **QRandomGenerator::securelySeeded** (), is always seeded from
    **QRandomGenerator::system** (), so it's not possible to make it produce
    identical sequences.

    **Bulk data**

    When operating in deterministic mode, QRandomGenerator may be used for bulk
    data generation. In fact, applications that do not need cryptographically-
    secure or true random data are advised to use a regular QRandomGenerator
    instead of **QRandomGenerator::system** () for their random data needs.

    For ease of use, QRandomGenerator provides a global object that can be
    easily used, as in the following example:

    int x = **QRandomGenerator** ::global()->generate();
            int y =
    **QRandomGenerator** ::global()->generate();
            int w =
    **QRandomGenerator** ::global()->bounded(16384);
            int h =
    **QRandomGenerator** ::global()->bounded(16384);

    **System-wide random number generator**

    **QRandomGenerator::system** () may be used to access the system-wide random
    number generator, which is cryptographically-safe on all systems that Qt
    runs on. This function will use hardware facilities to generate random
    numbers where available. On such systems, those facilities are true Random
    Number Generators. However, if they are true RNGs, those facilities have
    finite entropy sources and thus may fail to produce any results if their
    entropy pool is exhausted.

    If that happens, first the operating system then QRandomGenerator will fall
    back to Pseudo Random Number Generators of decreasing qualities (Qt's
    fallback generator being the simplest). Whether those generators are still
    of cryptographic quality is implementation-defined. Therefore,
    **QRandomGenerator::system** () should not be used for high-frequency random
    number generation, lest the entropy pool become empty. As a rule of thumb,
    this class should not be called upon to generate more than a kilobyte per
    second of random data (note: this may vary from system to system).

    If an application needs true RNG data in bulk, it should use the operating
    system facilities (such as `/dev/random` on Linux) directly and wait for
    entropy to become available. If the application requires PRNG engines of
    cryptographic quality but not of true randomness,
    **QRandomGenerator::system** () may still be used (see section below).

    If neither a true RNG nor a cryptographically secure PRNG are required,
    applications should instead use PRNG engines like QRandomGenerator's
    deterministic mode and those from the C++ Standard Library.
    **QRandomGenerator::system** () can be used to seed those.

    **Fallback quality**

    **QRandomGenerator::system** () uses the operating system facilities to
    obtain random numbers, which attempt to collect real entropy from the
    surrounding environment to produce true random numbers. However, it's
    possible that the entropy pool becomes exhausted, in which case the
    operating system will fall back to a pseudo-random engine for a time. Under
    no circumstances will **QRandomGenerator::system** () block, waiting for
    more entropy to be collected.

    The following operating systems guarantee that the results from their
    random-generation API will be of at least cryptographically-safe quality,
    even if the entropy pool is exhausted: Apple OSes (Darwin), BSDs, Linux,
    Windows. Barring a system installation problem (such as `/dev/urandom` not
    being readable by the current process), **QRandomGenerator::system** () will
    therefore have the same guarantees.

    On other operating systems, QRandomGenerator will fall back to a PRNG of
    good numeric distribution, but it cannot guarantee proper seeding in all
    cases. Please consult the OS documentation for more information.

    Applications that require QRandomGenerator not to fall back to non-
    cryptographic quality generators are advised to check their operating system
    documentation or restrict their deployment to one of the above.

    **Reentrancy and thread-safety**

    QRandomGenerator is reentrant, meaning that multiple threads can operate on
    this class at the same time, so long as they operate on different objects.
    If multiple threads need to share one PRNG sequence, external locking by a
    mutex is required.

    The exceptions are the objects returned by **QRandomGenerator::global** ()
    and **QRandomGenerator::system** (): those objects are thread-safe and may
    be used by any thread without external locking. Note that thread-safety does
    not extend to copying those objects: they should always be used by
    reference.

    **Standard C++ Library compatibility**

    QRandomGenerator is modeled after the requirements for random number engines
    in the C++ Standard Library and may be used in almost all contexts that the
    Standard Library engines can. Exceptions to the requirements are the
    following:

    * QRandomGenerator does not support seeding from another seed sequence-like
    class besides std::seed_seq itself;
      * QRandomGenerator is not comparable
    (but is copyable) or streamable to `std::ostream` or from `std::istream`.

    QRandomGenerator is also compatible with the uniform distribution classes
    `std::uniform_int_distribution` and `std:uniform_real_distribution`, as well
    as the free function `std::generate_canonical`. For example, the following
    code may be used to generate a floating-point number in the range [1, 2.5):

    std::uniform_real_distribution dist(1, 2.5);
            return
    dist(***QRandomGenerator** ::global());

    **See also** **QRandomGenerator64** .
    """

    @typing.overload
    def __init__(self, seed: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#QRandomGenerator

        **QRandomGenerator::QRandomGenerator(quint32 seedValue = 1)**

        Initializes this QRandomGenerator object with the value **seedValue** as
        the seed. Two objects constructed or reseeded with the same seed value
        will produce the same number sequence.

        **See also** **seed** () and **securelySeeded** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QRandomGenerator") -> None:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#QRandomGenerator-1

        **template <qsizetype N> QRandomGenerator::QRandomGenerator(const
        quint32 (&)[N] seedBuffer = N)**

        This is an overloaded function.

        Initializes this QRandomGenerator object with the values found in the
        array **seedBuffer** as the seed. Two objects constructed or reseeded
        with the same seed value will produce the same number sequence.

        **See also** **seed** () and **securelySeeded** ().
        """
        ...

    @staticmethod
    def securelySeeded() -> "QRandomGenerator":
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#securelySeeded

        **[static] QRandomGenerator QRandomGenerator::securelySeeded()**

        Returns a new **QRandomGenerator**  object that was securely seeded with
        **QRandomGenerator::system** (). This function will obtain the ideal
        seed size for the algorithm that **QRandomGenerator**  uses and is
        therefore the recommended way for creating a new **QRandomGenerator**
        object that will be kept for some time.

        Given the amount of data required to securely seed the deterministic
        engine, this function is somewhat expensive and should not be used for
        short-term uses of **QRandomGenerator**  (using it to generate fewer
        than 2600 bytes of random data is effectively a waste of resources). If
        the use doesn't require that much data, consider using
        **QRandomGenerator::global** () and not storing a **QRandomGenerator**
        object instead.

        **See also** **global** () and **system** ().
        """
        ...

    @staticmethod
    def global_() -> "QRandomGenerator":
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#global

        **[static] QRandomGenerator *QRandomGenerator::global()**

        Returns a pointer to a shared **QRandomGenerator**  that was seeded
        using **securelySeeded** (). This function should be used to create
        random data without the expensive creation of a securely-seeded
        **QRandomGenerator**  for a specific use or storing the rather large
        **QRandomGenerator**  object.

        For example, the following creates a random RGB color:

        return **QColor** ::fromRgb(**QRandomGenerator**
        ::global()->generate());

        Accesses to this object are thread-safe and it may therefore be used in
        any thread without locks. The object may also be copied and the sequence
        produced by the copy will be the same as the shared object will produce.
        Note, however, that if there are other threads accessing the global
        object, those threads may obtain samples at unpredictable intervals.

        **Note:** This function is **thread-safe** .

        **See also** **securelySeeded** () and **system** ().
        """
        ...

    @staticmethod
    def system() -> "QRandomGenerator":
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#system

        **[static] QRandomGenerator *QRandomGenerator::system()**

        Returns a pointer to a shared **QRandomGenerator**  that always uses the
        facilities provided by the operating system to generate random numbers.
        The system facilities are considered to be cryptographically safe on at
        least the following operating systems: Apple OSes (Darwin), BSDs, Linux,
        Windows. That may also be the case on other operating systems.

        They are also possibly backed by a true hardware random number
        generator. For that reason, the **QRandomGenerator**  returned by this
        function should not be used for bulk data generation. Instead, use it to
        seed **QRandomGenerator**  or a random engine from the <random> header.

        The object returned by this function is thread-safe and may be used in
        any thread without locks. It may also be copied and the resulting
        **QRandomGenerator**  will also access the operating system facilities,
        but they will not generate the same sequence.

        **Note:** This function is **thread-safe** .

        **See also** **securelySeeded** () and **global** ().
        """
        ...

    @staticmethod
    def max() -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#max

        **[static] QRandomGenerator::result_type QRandomGenerator::max()**

        Returns the maximum value that **QRandomGenerator**  may ever generate.
        That is, `std::numeric_limits<result_type>::max()`.

        **See also** **min** () and QRandomGenerator64::max().
        """
        ...

    @staticmethod
    def min() -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#min

        **[static] QRandomGenerator::result_type QRandomGenerator::min()**

        Returns the minimum value that **QRandomGenerator**  may ever generate.
        That is, 0.

        **See also** **max** () and QRandomGenerator64::min().
        """
        ...

    def discard(self, z: int) -> None:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#discard

        **void QRandomGenerator::discard(unsigned long long z )**

        Discards the next **z** entries from the sequence. This method is
        equivalent to calling **generate** () **z** times and discarding the
        result, as in:

        while (z--)
                    generator.generate();
        """
        ...

    def seed(self, seed: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#seed

        **void QRandomGenerator::seed(quint32 seed = 1)**

        Reseeds this object using the value **seed** as the seed.
        """
        ...

    def __call__(self) -> int:
        ...

    @typing.overload
    def bounded(self, highest: float) -> float:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#bounded

        **double QRandomGenerator::bounded(double highest )**

        Generates one random double in the range between 0 (inclusive) and
        **highest** (exclusive). This function is equivalent to and is
        implemented as:

        return generateDouble() * highest;

        If the **highest** parameter is negative, the result will be negative
        too; if it is infinite or NaN, the result will be infinite or NaN too
        (that is, not random).

        **See also** **generateDouble** () and bounded().
        """
        ...

    @typing.overload
    def bounded(self, lowest: int, highest: int) -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#bounded-1

        **quint32 QRandomGenerator::bounded(quint32 highest )**

        This is an overloaded function.

        Generates one random 32-bit quantity in the range between 0 (inclusive)
        and **highest** (exclusive). The same result may also be obtained by
        using [`std::uniform_int_distribution`**  with parameters 0 and `highest
        - 1`. That class can also be used to obtain quantities larger than 32
        bits; for 64 bits, the 64-bit bounded() overload can be used too.

        For example, to obtain a value between 0 and 255 (inclusive), one would
        write:

        **quint32**  v = **QRandomGenerator** ::global()->bounded(256);

        Naturally, the same could also be obtained by masking the result of
        **generate** () to only the lower 8 bits. Either solution is as
        efficient.

        Note that this function cannot be used to obtain values in the full
        32-bit range of quint32. Instead, use **generate** ().

        **See also** **generate** (), **generate64** (), and **generateDouble**
        ().
        """
        ...

    @typing.overload
    def bounded(self, highest: int) -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#bounded-2

        **quint32 QRandomGenerator::bounded(quint32 lowest , quint32 highest )**

        This is an overloaded function.

        Generates one random 32-bit quantity in the range between **lowest**
        (inclusive) and **highest** (exclusive). The **highest** parameter must
        be greater than **lowest**.

        The same result may also be obtained by using
        [`std::uniform_int_distribution`**  with parameters **lowest** and `\\a
        highest - 1`. That class can also be used to obtain quantities larger
        than 32 bits.

        For example, to obtain a value between 1000 (incl.) and 2000 (excl.),
        one would write:

        **quint32**  v = **QRandomGenerator** ::global()->bounded(1000, 2000);

        Note that this function cannot be used to obtain values in the full
        32-bit range of quint32. Instead, use **generate** ().

        **See also** **generate** (), **generate64** (), and **generateDouble**
        ().
        """
        ...

    def generateDouble(self) -> float:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#generateDouble

        **double QRandomGenerator::generateDouble()**

        Generates one random qreal in the canonical range [0, 1) (that is,
        inclusive of zero and exclusive of 1).

        This function is equivalent to:

        QRandomGenerator64 rd;
                return std::generate_canonical<**qreal**
        , std::numeric_limits<**qreal** >::digits>(rd);

        The same may also be obtained by using
        [`std::uniform_real_distribution`**  with parameters 0 and 1.

        **See also** **generate** (), **generate64** (), and **bounded** ().
        """
        ...

    def generate64(self) -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#generate64

        **quint64 QRandomGenerator::generate64()**

        Generates a 64-bit random quantity and returns it.

        **See also** **operator()** () and **generate** ().
        """
        ...

    def generate(self) -> int:
        """
        https://doc.qt.io/qt-6/qrandomgenerator.html#generate

        **quint32 QRandomGenerator::generate()**

        Generates a 32-bit random quantity and returns it.

        **See also** **operator()** () and **generate64** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QTypeRevision(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qtyperevision.html

    **Detailed Description**

    Use this class to describe revisions of a type. Compatible revisions can be
    expressed as increments of the minor version. Breaking changes can be
    expressed as increments of the major version. The return values of
    **QMetaMethod::revision** () and **QMetaProperty::revision** () can be
    passed to **QTypeRevision::fromEncodedVersion** (). The resulting major and
    minor versions specify in which Qt versions the properties and methods were
    added.

    **See also** **QMetaMethod::revision** () and **QMetaProperty::revision**
    ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#QTypeRevision

        **QTypeRevision::QTypeRevision()**

        Produces an invalid revision.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QTypeRevision") -> None:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#QTypeRevision

        **QTypeRevision::QTypeRevision()**

        Produces an invalid revision.

        **See also** **isValid** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def toEncodedVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#toEncodedVersion

        **template <typename Integer, if_valid_value_type<Integer>> Integer
        QTypeRevision::toEncodedVersion() const**

        Transforms the revision into an integer value, encoding the minor
        version into the least significant byte, and the major version into the
        second least significant byte.

        `Integer` needs to be at least 16 bits wide, and must not have a sign
        bit in the least significant 16 bits.

        **See also** **fromEncodedVersion** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#isValid

        **bool QTypeRevision::isValid() const**

        Returns true if the major version or the minor version is known,
        otherwise false.

        **See also** **hasMajorVersion** () and **hasMinorVersion** ().
        """
        ...

    def minorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#minorVersion

        **quint8 QTypeRevision::minorVersion() const**

        Returns the minor version encoded in the revision.

        **See also** **hasMinorVersion** () and **majorVersion** ().
        """
        ...

    def hasMinorVersion(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#hasMinorVersion

        **bool QTypeRevision::hasMinorVersion() const**

        Returns true if the minor version is known, otherwise false.

        **See also** **minorVersion** () and **hasMajorVersion** ().
        """
        ...

    def majorVersion(self) -> int:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#majorVersion

        **quint8 QTypeRevision::majorVersion() const**

        Returns the major version encoded in the revision.

        **See also** **hasMajorVersion** () and **minorVersion** ().
        """
        ...

    def hasMajorVersion(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtyperevision.html#hasMajorVersion

        **bool QTypeRevision::hasMajorVersion() const**

        Returns true if the major version is known, otherwise false.

        **See also** **majorVersion** () and **hasMinorVersion** ().
        """
        ...

    @staticmethod
    def zero() -> "QTypeRevision":
        """
        https://doc.qt.io/qt-6/qtyperevision.html#zero

        **[static] QTypeRevision QTypeRevision::zero()**

        Produces a **QTypeRevision**  with major and minor version `0`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore


class QStyleHints(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qstylehints.html

    **Detailed Description**

    An object of this class, obtained from **QGuiApplication** , provides access
    to certain global user interface parameters of the current platform.

    Access is read only; typically the platform itself provides the user a way
    to tune these parameters.

    Access to these parameters are useful when implementing custom user
    interface components, in that they allow the components to exhibit the same
    behaviour and feel as other components.

    **See also** **QGuiApplication::styleHints** ().
    """

    def touchDoubleTapDistance(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#touchDoubleTapDistance-prop

        **[read-only, since 5.14] touchDoubleTapDistance : const int**

        This property holds the maximum distance, in pixels, that a finger can
        be moved between two consecutive taps and still have it detected as a
        double-tap

        This property was introduced in Qt 5.14.

        **Access functions:**

        int **touchDoubleTapDistance** () const
        """
        ...

    def mouseDoubleClickDistance(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#mouseDoubleClickDistance-prop

        **[read-only, since 5.14] mouseDoubleClickDistance : const int**

        This property holds the maximum distance, in pixels, that the mouse can
        be moved between two consecutive mouse clicks and still have it detected
        as a double-click

        This property was introduced in Qt 5.14.

        **Access functions:**

        int **mouseDoubleClickDistance** () const
        """
        ...

    def setShowShortcutsInContextMenus(self, showShortcutsInContextMenus: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstylehints.html#showShortcutsInContextMenus-prop

        **[since 5.10] showShortcutsInContextMenus : bool**

        `true` if the platform normally shows shortcut key sequences in context
        menus, otherwise `false`.

        Since Qt 5.13, the setShowShortcutsInContextMenus() function can be used
        to override the platform default.

        This property was introduced in Qt 5.10.

        **Access functions:**

        bool **showShortcutsInContextMenus** () const
        void
        **setShowShortcutsInContextMenus** (bool **showShortcutsInContextMenus**
        )

        **Notifier signal:**

        void **showShortcutsInContextMenusChanged** (bool)
        """
        ...

    def mouseQuickSelectionThreshold(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#mouseQuickSelectionThreshold-
        prop

        **[since 5.11] mouseQuickSelectionThreshold : const int**

        Quick selection mouse threshold in **QLineEdit** .

        This property defines how much the mouse cursor should be moved along
        the y axis to trigger a quick selection during a normal **QLineEdit**
        text selection.

        If the property value is less than or equal to 0, the quick selection
        feature is disabled.

        This property was introduced in Qt 5.11.

        **Access functions:**

        int **mouseQuickSelectionThreshold** () const

        **Notifier signal:**

        void **mouseQuickSelectionThresholdChanged** (int **threshold** )
        """
        ...

    def showShortcutsInContextMenus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#showShortcutsInContextMenus-prop

        **[since 5.10] showShortcutsInContextMenus : bool**

        `true` if the platform normally shows shortcut key sequences in context
        menus, otherwise `false`.

        Since Qt 5.13, the setShowShortcutsInContextMenus() function can be used
        to override the platform default.

        This property was introduced in Qt 5.10.

        **Access functions:**

        bool **showShortcutsInContextMenus** () const
        void
        **setShowShortcutsInContextMenus** (bool **showShortcutsInContextMenus**
        )

        **Notifier signal:**

        void **showShortcutsInContextMenusChanged** (bool)
        """
        ...

    def wheelScrollLines(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#wheelScrollLines-prop

        **[read-only, since 5.9] wheelScrollLines : const int**

        Number of lines to scroll by default for each wheel click.

        This property was introduced in Qt 5.9.

        **Access functions:**

        int **wheelScrollLines** () const

        **Notifier signal:**

        void **wheelScrollLinesChanged** (int **scrollLines** )
        """
        ...

    def setUseHoverEffects(self, useHoverEffects: bool) -> None:
        """
        https://doc.qt.io/qt-6/qstylehints.html#useHoverEffects-prop

        **[since 5.8] useHoverEffects : bool**

        This property holds whether UI elements use hover effects.

        This property is `true` if UI elements should use hover effects. This is
        the standard behavior on desktop platforms with a mouse pointer, whereas
        on touch platforms the overhead of hover event delivery can be avoided.

        This property was introduced in Qt 5.8.

        **Access functions:**

        bool **useHoverEffects** () const
        void **setUseHoverEffects** (bool
        **useHoverEffects** )

        **Notifier signal:**

        void **useHoverEffectsChanged** (bool **useHoverEffects** )
        """
        ...

    def useHoverEffects(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#useHoverEffects-prop

        **[since 5.8] useHoverEffects : bool**

        This property holds whether UI elements use hover effects.

        This property is `true` if UI elements should use hover effects. This is
        the standard behavior on desktop platforms with a mouse pointer, whereas
        on touch platforms the overhead of hover event delivery can be avoided.

        This property was introduced in Qt 5.8.

        **Access functions:**

        bool **useHoverEffects** () const
        void **setUseHoverEffects** (bool
        **useHoverEffects** )

        **Notifier signal:**

        void **useHoverEffectsChanged** (bool **useHoverEffects** )
        """
        ...

    def showIsMaximized(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#showIsMaximized-prop

        **[read-only, since 5.6] showIsMaximized : const bool**

        This property holds whether the platform defaults to maximized windows.

        This property is `true` if the platform defaults to windows being
        maximized, otherwise `false`.

        **Note:** The platform may still choose to show certain windows non-
        maximized, such as popups or dialogs. This property only reports the
        default behavior.

        This property was introduced in Qt 5.6.

        **Access functions:**

        bool **showIsMaximized** () const

        **See also** **QWindow::show** () and **showIsFullScreen** ().
        """
        ...

    def singleClickActivation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#singleClickActivation-prop

        **[read-only, since 5.5] singleClickActivation : const bool**

        This property holds whether items are activated by single or double
        click.

        This property is `true` if items should be activated by single click,
        `false` if they should be activated by double click instead.

        This property was introduced in Qt 5.5.

        **Access functions:**

        bool **singleClickActivation** () const
        """
        ...

    def tabFocusBehavior(self) -> QtCore.Qt.TabFocusBehavior:
        """
        https://doc.qt.io/qt-6/qstylehints.html#tabFocusBehavior-prop

        **[read-only, since 5.5] tabFocusBehavior : const Qt::TabFocusBehavior**

        This property holds the focus behavior on press of the tab key.

        **Note:** Do not bind this value in QML because the change notifier
        signal is not implemented yet.

        This property was introduced in Qt 5.5.

        **Access functions:**

        Qt::TabFocusBehavior **tabFocusBehavior** () const

        **Notifier signal:**

        void **tabFocusBehaviorChanged** (Qt::TabFocusBehavior
        **tabFocusBehavior** )
        """
        ...

    def mousePressAndHoldInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#mousePressAndHoldInterval-prop

        **[read-only, since 5.3] mousePressAndHoldInterval : const int**

        This property holds the time limit in milliseconds that activates a
        press and hold.

        This property was introduced in Qt 5.3.

        **Access functions:**

        int **mousePressAndHoldInterval** () const

        **Notifier signal:**

        void **mousePressAndHoldIntervalChanged** (int
        **mousePressAndHoldInterval** )
        """
        ...

    def setFocusOnTouchRelease(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#setFocusOnTouchRelease-prop

        **[read-only] setFocusOnTouchRelease : const bool**

        This property holds the event that should set input focus on focus
        objects.

        This property is `true` if focus objects (line edits etc) should receive
        input focus after a touch/mouse release. This is normal behavior on
        touch platforms. On desktop platforms, the standard is to set focus
        already on touch/mouse press.

        **Access functions:**

        bool **setFocusOnTouchRelease** () const
        """
        ...

    def passwordMaskCharacter(self) -> str:
        """
        https://doc.qt.io/qt-6/qstylehints.html#passwordMaskCharacter-prop

        **[read-only] passwordMaskCharacter : const QChar**

        This property holds the character used to mask the characters typed into
        text input fields in password mode.

        **Access functions:**

        QChar **passwordMaskCharacter** () const
        """
        ...

    def useRtlExtensions(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#useRtlExtensions-prop

        **[read-only] useRtlExtensions : const bool**

        This property holds the writing direction.

        This property is `true` if right-to-left writing direction is enabled,
        otherwise `false`.

        **Access functions:**

        bool **useRtlExtensions** () const
        """
        ...

    def fontSmoothingGamma(self) -> float:
        """
        https://doc.qt.io/qt-6/qstylehints.html#fontSmoothingGamma-prop

        **[read-only] fontSmoothingGamma : const qreal**

        This property holds the gamma value used in font smoothing.

        **Access functions:**

        qreal **fontSmoothingGamma** () const
        """
        ...

    def passwordMaskDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#passwordMaskDelay-prop

        **[read-only] passwordMaskDelay : const int**

        This property holds the time, in milliseconds, a typed letter is
        displayed unshrouded in a text input field in password mode.

        **Access functions:**

        int **passwordMaskDelay** () const
        """
        ...

    def showIsFullScreen(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstylehints.html#showIsFullScreen-prop

        **[read-only] showIsFullScreen : const bool**

        This property holds whether the platform defaults to fullscreen windows.

        This property is `true` if the platform defaults to windows being
        fullscreen, otherwise `false`.

        **Note:** The platform may still choose to show certain windows non-
        fullscreen, such as popups or dialogs. This property only reports the
        default behavior.

        **Access functions:**

        bool **showIsFullScreen** () const

        **See also** **QWindow::show** () and **showIsMaximized** ().
        """
        ...

    def cursorFlashTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#cursorFlashTime-prop

        **[read-only] cursorFlashTime : const int**

        This property holds the text cursor's flash (blink) time in
        milliseconds.

        The flash time is the time used to display, invert and restore the caret
        display. Usually the text cursor is displayed for half the cursor flash
        time, then hidden for the same amount of time.

        **Access functions:**

        int **cursorFlashTime** () const

        **Notifier signal:**

        void **cursorFlashTimeChanged** (int **cursorFlashTime** )
        """
        ...

    def keyboardAutoRepeatRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#keyboardAutoRepeatRate-prop

        **[read-only] keyboardAutoRepeatRate : const int**

        This property holds the rate, in events per second, in which additional
        repeated key presses will automatically be generated if a key is being
        held down.

        **Access functions:**

        int **keyboardAutoRepeatRate** () const
        """
        ...

    def keyboardInputInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#keyboardInputInterval-prop

        **[read-only] keyboardInputInterval : const int**

        This property holds the time limit, in milliseconds, that distinguishes
        a key press from two consecutive key presses.

        **Access functions:**

        int **keyboardInputInterval** () const

        **Notifier signal:**

        void **keyboardInputIntervalChanged** (int **keyboardInputInterval** )
        """
        ...

    def startDragVelocity(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#startDragVelocity-prop

        **[read-only] startDragVelocity : const int**

        This property holds the limit for the velocity, in pixels per second,
        that the mouse may be moved, with a button held down, for a drag and
        drop operation to begin. A value of 0 means there is no such limit.

        **Access functions:**

        int **startDragVelocity** () const

        **See also** **startDragDistance**  and **Drag and Drop** .
        """
        ...

    def startDragTime(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#startDragTime-prop

        **[read-only] startDragTime : const int**

        This property holds the time, in milliseconds, that a mouse button must
        be held down before a drag and drop operation will begin.

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has held down a mouse button for
        a certain amount of time, you should use this property's value as the
        delay.

        **Access functions:**

        int **startDragTime** () const

        **Notifier signal:**

        void **startDragTimeChanged** (int **startDragTime** )

        **See also** **startDragDistance**  and **Drag and Drop** .
        """
        ...

    def startDragDistance(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#startDragDistance-prop

        **[read-only] startDragDistance : const int**

        This property holds the distance, in pixels, that the mouse must be
        moved with a button held down before a drag and drop operation will
        begin.

        If you support drag and drop in your application, and want to start a
        drag and drop operation after the user has moved the cursor a certain
        distance with a button held down, you should use this property's value
        as the minimum distance required.

        For example, if the mouse position of the click is stored in `startPos`
        and the current position (e.g. in the mouse move event) is `currentPos`,
        you can find out if a drag should be started with code like this:

        int main(int argc, char *argv[])
            {
                **QApplication**
        ::setDesktopSettingsAware(false);
                **QApplication**  app(argc,
        argv);
                ...
                return app.exec();
            }

        **Access functions:**

        int **startDragDistance** () const

        **Notifier signal:**

        void **startDragDistanceChanged** (int **startDragDistance** )

        **See also** **startDragTime** , **QPoint::manhattanLength** (), and
        **Drag and Drop** .
        """
        ...

    def mouseDoubleClickInterval(self) -> int:
        """
        https://doc.qt.io/qt-6/qstylehints.html#mouseDoubleClickInterval-prop

        **[read-only] mouseDoubleClickInterval : const int**

        This property holds the time limit in milliseconds that distinguishes a
        double click from two consecutive mouse clicks.

        **Access functions:**

        int **mouseDoubleClickInterval** () const

        **Notifier signal:**

        void **mouseDoubleClickIntervalChanged** (int
        **mouseDoubleClickInterval** )
        """
        ...

    @property
    def cursorFlashTimeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def keyboardInputIntervalChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mouseDoubleClickIntervalChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mousePressAndHoldIntervalChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mouseQuickSelectionThresholdChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def showShortcutsInContextMenusChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def startDragDistanceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def startDragTimeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def tabFocusBehaviorChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def useHoverEffectsChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def wheelScrollLinesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QObject(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qobject.html

    **Detailed Description**

    QObject is the heart of the Qt **Object Model** . The central feature in
    this model is a very powerful mechanism for seamless object communication
    called **signals and slots** . You can connect a signal to a slot with
    **connect** () and destroy the connection with **disconnect** (). To avoid
    never ending notification loops you can temporarily block signals with
    **blockSignals** (). The protected functions **connectNotify** () and
    **disconnectNotify** () make it possible to track connections.

    QObjects organize themselves in **object trees** . When you create a QObject
    with another object as parent, the object will automatically add itself to
    the parent's **children** () list. The parent takes ownership of the object;
    i.e., it will automatically delete its children in its destructor. You can
    look for an object by name and optionally type using **findChild** () or
    **findChildren** ().

    Every object has an **objectName** () and its class name can be found via
    the corresponding **metaObject** () (see **QMetaObject::className** ()). You
    can determine whether the object's class inherits another class in the
    QObject inheritance hierarchy by using the **inherits** () function.

    When an object is deleted, it emits a **destroyed** () signal. You can catch
    this signal to avoid dangling references to QObjects.

    QObjects can receive events through **event** () and filter the events of
    other objects. See **installEventFilter** () and **eventFilter** () for
    details. A convenience handler, **childEvent** (), can be reimplemented to
    catch child events.

    Last but not least, QObject provides the basic timer support in Qt; see
    **QTimer**  for high-level support for timers.

    Notice that the **Q_OBJECT**  macro is mandatory for any object that
    implements signals, slots or properties. You also need to run the **Meta
    Object Compiler**  on the source file. We strongly recommend the use of this
    macro in all subclasses of QObject regardless of whether or not they
    actually use signals, slots and properties, since failure to do so may lead
    certain functions to exhibit strange behavior.

    All Qt widgets inherit QObject. The convenience function **isWidgetType** ()
    returns whether an object is actually a widget. It is much faster than
    **qobject_cast** <**QWidget**  *>( **obj** ) or **obj** ->**inherits**
    ("**QWidget** ").

    Some QObject functions, e.g. **children** (), return a **QObjectList** .
    **QObjectList**  is a typedef for **QList** <QObject *>.

    **Thread Affinity**

    A QObject instance is said to have a **thread affinity** , or that it
    **lives** in a certain thread. When a QObject receives a **queued signal**
    or a **posted event** , the slot or event handler will run in the thread
    that the object lives in.

    **Note:** If a QObject has no thread affinity (that is, if **thread** ()
    returns zero), or if it lives in a thread that has no running event loop,
    then it cannot receive queued signals or posted events.

    By default, a QObject lives in the thread in which it is created. An
    object's thread affinity can be queried using **thread** () and changed
    using **moveToThread** ().

    All QObjects must live in the same thread as their parent. Consequently:

    * **setParent** () will fail if the two QObjects involved live in different
    threads.
      * When a QObject is moved to another thread, all its children
    will be automatically moved too.
      * **moveToThread** () will fail if the
    QObject has a parent.
      * If QObjects are created within **QThread::run**
    (), they cannot become children of the **QThread**  object because the
    **QThread**  does not live in the thread that calls **QThread::run** ().

    **Note:** A QObject's member variables **do not** automatically become its
    children. The parent-child relationship must be set by either passing a
    pointer to the child's **constructor** , or by calling **setParent** ().
    Without this step, the object's member variables will remain in the old
    thread when **moveToThread** () is called.

    **No Copy Constructor or Assignment Operator**

    QObject has neither a copy constructor nor an assignment operator. This is
    by design. Actually, they are declared, but in a `private` section with the
    macro **Q_DISABLE_COPY** (). In fact, all Qt classes derived from QObject
    (direct or indirect) use this macro to declare their copy constructor and
    assignment operator to be private. The reasoning is found in the discussion
    on **Identity vs Value**  on the Qt **Object Model**  page.

    The main consequence is that you should use pointers to QObject (or to your
    QObject subclass) where you might otherwise be tempted to use your QObject
    subclass as a value. For example, without a copy constructor, you can't use
    a subclass of QObject as the value to be stored in one of the container
    classes. You must store pointers.

    **Auto-Connection**

    Qt's meta-object system provides a mechanism to automatically connect
    signals and slots between QObject subclasses and their children. As long as
    objects are defined with suitable object names, and slots follow a simple
    naming convention, this connection can be performed at run-time by the
    **QMetaObject::connectSlotsByName** () function.

    **uic**  generates code that invokes this function to enable auto-connection
    to be performed between widgets on forms created with **Qt Designer**. More
    information about using auto-connection with **Qt Designer** is given in the
    **Using a Designer UI File in Your Application**  section of the **Qt
    Designer** manual.

    **Dynamic Properties**

    From Qt 4.2, dynamic properties can be added to and removed from QObject
    instances at run-time. Dynamic properties do not need to be declared at
    compile-time, yet they provide the same advantages as static properties and
    are manipulated using the same API - using **property** () to read them and
    **setProperty** () to write them.

    From Qt 4.3, dynamic properties are supported by **Qt Designer** , and both
    standard Qt widgets and user-created forms can be given dynamic properties.

    **Internationalization (I18n)**

    All QObject subclasses support Qt's translation features, making it possible
    to translate an application's user interface into different languages.

    To make user-visible text translatable, it must be wrapped in calls to the
    **tr** () function. This is explained in detail in the **Writing Source Code
    for Translation**  document.

    **See also** **QMetaObject** , **QPointer** , **QObjectCleanupHandler** ,
    **Q_DISABLE_COPY** (), and **Object Trees & Ownership** .
    """

    staticMetaObject = ...

    def __init__(self, parent: typing.Optional["QObject"] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#QObject

        **[invokable] QObject::QObject(QObject * parent = nullptr)**

        Constructs an object with parent object **parent**.

        The parent of an object may be viewed as the object's owner. For
        instance, a **dialog box**  is the parent of the **OK** and **Cancel**
        buttons it contains.

        The destructor of a parent object destroys all child objects.

        Setting **parent** to `nullptr` constructs an object with no parent. If
        the object is a widget, it will become a top-level window.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **parent** (), **findChild** (), and **findChildren** ().
        """
        ...

    @typing.overload
    @staticmethod
    def disconnect(a0: "QMetaObject.Connection") -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#disconnect

        **[static] bool QObject::disconnect(const QObject * sender , const char
        * signal , const QObject * receiver , const char * method )**

        Disconnects **signal** in object **sender** from **method** in object
        **receiver**. Returns `true` if the connection is successfully broken;
        otherwise returns `false`.

        A signal-slot connection is removed when either of the objects involved
        are destroyed.

        disconnect() is typically used in three ways, as the following examples
        demonstrate.

        1. Disconnect everything connected to an object's signals:
        disconnect(myObject, nullptr, nullptr, nullptr);

        equivalent to the non-
        static overloaded function


                myObject->disconnect();

          2.
        Disconnect everything connected to a specific signal:
        disconnect(myObject, SIGNAL(mySignal()), nullptr, nullptr);

        equivalent
        to the non-static overloaded function
        myObject->disconnect(SIGNAL(mySignal()));

          3. Disconnect a specific
        receiver:

                disconnect(myObject, nullptr, myReceiver,
        nullptr);

        equivalent to the non-static overloaded function
        myObject->disconnect(myReceiver);

        `nullptr` may be used as a wildcard, meaning "any signal", "any
        receiving object", or "any slot in the receiving object", respectively.

        The **sender** may never be `nullptr`. (You cannot disconnect signals
        from more than one object in a single call.)

        If **signal** is `nullptr`, it disconnects **receiver** and **method**
        from any signal. If not, only the specified signal is disconnected.

        If **receiver** is `nullptr`, it disconnects anything connected to
        **signal**. If not, slots in objects other than **receiver** are not
        disconnected.

        If **method** is `nullptr`, it disconnects anything that is connected to
        **receiver**. If not, only slots named **method** will be disconnected,
        and all other slots are left alone. The **method** must be `nullptr` if
        **receiver** is left out, so you cannot disconnect a specifically-named
        slot on all objects.

        **Note:** Disconnecting all signal-slot connections will also disconnect
        the **QObject::destroyed** () signal if it is connected. Doing so can
        adversely affect classes that rely on this signal for cleaning up
        resources. It is recommended to disconnect only the specific signals
        that were connected by application code.

        **Note:** This function is **thread-safe** .

        **See also** **connect** ().
        """
        ...

    @typing.overload
    def disconnect(self) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#disconnect-1

        **[static] bool QObject::disconnect(const QObject * sender , const
        QMetaMethod & signal , const QObject * receiver , const QMetaMethod &
        method )**

        Disconnects **signal** in object **sender** from **method** in object
        **receiver**. Returns `true` if the connection is successfully broken;
        otherwise returns `false`.

        This function provides the same possibilities like `disconnect(const
        QObject *sender, const char *signal, const QObject *receiver, const char
        *method)` but uses **QMetaMethod**  to represent the signal and the
        method to be disconnected.

        Additionally this function returns false and no signals and slots
        disconnected if:

        1.  **signal** is not a member of sender class or one of its parent
        classes.
          2. **method** is not a member of receiver class or one of its
        parent classes.
          3. **signal** instance represents not a signal.

        QMetaMethod() may be used as wildcard in the meaning "any signal" or
        "any slot in receiving object". In the same way `nullptr` can be used
        for **receiver** in the meaning "any receiving object". In this case
        method should also be QMetaMethod(). **sender** parameter should be
        never `nullptr`.

        **Note:** Disconnecting all signal-slot connections will also disconnect
        the **QObject::destroyed** () signal if it is connected. Doing so can
        adversely affect classes that rely on this signal for cleaning up
        resources. It is recommended to disconnect only the specific signals
        that were connected by application code.

        **See also** **disconnect** (const QObject *sender, const char *signal,
        const QObject *receiver, const char *method).
        """
        ...

    def isSignalConnected(self, signal: "QMetaMethod") -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#isSignalConnected

        **[protected, since 5.0] bool QObject::isSignalConnected(const
        QMetaMethod & signal ) const**

        Returns `true` if the **signal** is connected to at least one receiver,
        otherwise returns `false`.

        **signal** must be a signal member of this object, otherwise the
        behaviour is undefined.

        static const **QMetaMethod**  valueChangedSignal = **QMetaMethod**
        ::fromSignal(&MyObject::valueChanged);
            if
        (isSignalConnected(valueChangedSignal)) {
                **QByteArray**  data;
        data = get_the_value();       // expensive operation
                emit
        valueChanged(data);
            }

        As the code snippet above illustrates, you can use this function to
        avoid emitting a signal that nobody listens to.

        **Warning:** This function violates the object-oriented principle of
        modularity. However, it might be useful when you need to perform
        expensive initialization only if something is connected to a signal.

        This function was introduced in Qt 5.0.
        """
        ...

    def senderSignalIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qobject.html#senderSignalIndex

        **[protected] int QObject::senderSignalIndex() const**

        Returns the meta-method index of the signal that called the currently
        executing slot, which is a member of the class returned by **sender**
        (). If called outside of a slot activated by a signal, -1 is returned.

        For signals with default parameters, this function will always return
        the index with all parameters, regardless of which was used with
        **connect** (). For example, the signal `destroyed(QObject *obj =
        \\nullptr)` will have two different indexes (with and without the
        parameter), but this function will always return the index with a
        parameter. This does not apply when overloading signals with different
        parameters.

        **Warning:** This function violates the object-oriented principle of
        modularity. However, getting access to the signal index might be useful
        when many signals are connected to a single slot.

        **Warning:** The return value of this function is not valid when the
        slot is called via a **Qt::DirectConnection**  from a thread different
        from this object's thread. Do not use this function in this type of
        scenario.

        **See also** **sender** (), **QMetaObject::indexOfSignal** (), and
        **QMetaObject::method** ().
        """
        ...

    def disconnectNotify(self, signal: "QMetaMethod") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#disconnectNotify

        **[virtual protected, since 5.0] void QObject::disconnectNotify(const
        QMetaMethod & signal )**

        This virtual function is called when something has been disconnected
        from **signal** in this object.

        See **connectNotify** () for an example of how to compare **signal**
        with a specific signal.

        If all signals were disconnected from this object (e.g., the signal
        argument to **disconnect** () was `nullptr`), disconnectNotify() is only
        called once, and the **signal** will be an invalid **QMetaMethod**
        (**QMetaMethod::isValid** () returns `false`).

        **Warning:** This function violates the object-oriented principle of
        modularity. However, it might be useful for optimizing access to
        expensive resources.

        **Warning:** This function is called from the thread which performs the
        disconnection, which may be a different thread from the thread in which
        this object lives. This function may also be called with a **QObject**
        internal mutex locked. It is therefore not allowed to re-enter any of
        any **QObject**  functions from your reimplementation and if you lock a
        mutex in your reimplementation, make sure that you don't call
        **QObject**  functions with that mutex held in other places or it will
        result in a deadlock.

        This function was introduced in Qt 5.0.

        **See also** **disconnect** () and **connectNotify** ().
        """
        ...

    def connectNotify(self, signal: "QMetaMethod") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#connectNotify

        **[virtual protected, since 5.0] void QObject::connectNotify(const
        QMetaMethod & signal )**

        This virtual function is called when something has been connected to
        **signal** in this object.

        If you want to compare **signal** with a specific signal, you can use
        **QMetaMethod::fromSignal** () as follows:

        if (signal == **QMetaMethod** ::fromSignal(&MyObject::valueChanged)) {
        // signal is valueChanged
            }

        **Warning:** This function violates the object-oriented principle of
        modularity. However, it might be useful when you need to perform
        expensive initialization only if something is connected to a signal.

        **Warning:** This function is called from the thread which performs the
        connection, which may be a different thread from the thread in which
        this object lives.

        This function was introduced in Qt 5.0.

        **See also** **connect** () and **disconnectNotify** ().
        """
        ...

    def customEvent(self, a0: "QEvent") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#customEvent

        **[virtual protected] void QObject::customEvent(QEvent * event )**

        This event handler can be reimplemented in a subclass to receive custom
        events. Custom events are user-defined events with a type value at least
        as large as the **QEvent::User**  item of the **QEvent::Type**  enum,
        and is typically a **QEvent**  subclass. The event is passed in the
        **event** parameter.

        **See also** **event** () and **QEvent** .
        """
        ...

    def childEvent(self, a0: "QChildEvent") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#childEvent

        **[virtual protected] void QObject::childEvent(QChildEvent * event )**

        This event handler can be reimplemented in a subclass to receive child
        events. The event is passed in the **event** parameter.

        **QEvent::ChildAdded**  and **QEvent::ChildRemoved**  events are sent to
        objects when children are added or removed. In both cases you can only
        rely on the child being a **QObject** , or if **isWidgetType** ()
        returns `true`, a **QWidget** . (This is because, in the **ChildAdded**
        case, the child is not yet fully constructed, and in the
        **ChildRemoved**  case it might have been destructed already).

        **QEvent::ChildPolished**  events are sent to widgets when children are
        polished, or when polished children are added. If you receive a child
        polished event, the child's construction is usually completed. However,
        this is not guaranteed, and multiple polish events may be delivered
        during the execution of a widget's constructor.

        For every child widget, you receive one **ChildAdded**  event, zero or
        more **ChildPolished**  events, and one **ChildRemoved**  event.

        The **ChildPolished**  event is omitted if a child is removed
        immediately after it is added. If a child is polished several times
        during construction and destruction, you may receive several child
        polished events for the same child, each time with a different virtual
        table.

        **See also** **event** ().
        """
        ...

    def timerEvent(self, a0: "QTimerEvent") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#timerEvent

        **[virtual protected] void QObject::timerEvent(QTimerEvent * event )**

        This event handler can be reimplemented in a subclass to receive timer
        events for the object.

        **QTimer**  provides a higher-level interface to the timer
        functionality, and also more general information about timers. The timer
        event is passed in the **event** parameter.

        **See also** **startTimer** (), **killTimer** (), and **event** ().
        """
        ...

    def receivers(self, signal: PYQT_SIGNAL) -> int:
        """
        https://doc.qt.io/qt-6/qobject.html#receivers

        **[protected] int QObject::receivers(const char * signal ) const**

        Returns the number of receivers connected to the **signal**.

        Since both slots and signals can be used as receivers for signals, and
        the same connections can be made many times, the number of receivers is
        the same as the number of connections made from this signal.

        When calling this function, you can use the `SIGNAL()` macro to pass a
        specific signal:

        if (receivers(SIGNAL(valueChanged(**QByteArray** ))) > 0) {
        **QByteArray**  data;
                get_the_value(&data);       // expensive
        operation
                emit valueChanged(data);
            }

        **Warning:** This function violates the object-oriented principle of
        modularity. However, it might be useful when you need to perform
        expensive initialization only if something is connected to a signal.

        **See also** **isSignalConnected** ().
        """
        ...

    def sender(self) -> "QObject":
        """
        https://doc.qt.io/qt-6/qobject.html#sender

        **[protected] QObject *QObject::sender() const**

        Returns a pointer to the object that sent the signal, if called in a
        slot activated by a signal; otherwise it returns `nullptr`. The pointer
        is valid only during the execution of the slot that calls this function
        from this object's thread context.

        The pointer returned by this function becomes invalid if the sender is
        destroyed, or if the slot is disconnected from the sender's signal.

        **Warning:** This function violates the object-oriented principle of
        modularity. However, getting access to the sender might be useful when
        many signals are connected to a single slot.

        **Warning:** As mentioned above, the return value of this function is
        not valid when the slot is called via a **Qt::DirectConnection**  from a
        thread different from this object's thread. Do not use this function in
        this type of scenario.

        **See also** **senderSignalIndex** ().
        """
        ...

    def deleteLater(self) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#deleteLater

        **[slot] void QObject::deleteLater()**

        Schedules this object for deletion.

        The object will be deleted when control returns to the event loop. If
        the event loop is not running when this function is called (e.g.
        deleteLater() is called on an object before **QCoreApplication::exec**
        ()), the object will be deleted once the event loop is started. If
        deleteLater() is called after the main event loop has stopped, the
        object will not be deleted. Since Qt 4.8, if deleteLater() is called on
        an object that lives in a thread with no running event loop, the object
        will be destroyed when the thread finishes.

        Note that entering and leaving a new event loop (e.g., by opening a
        modal dialog) will **not** perform the deferred deletion; for the object
        to be deleted, the control must return to the event loop from which
        deleteLater() was called. This does not apply to objects deleted while a
        previous, nested event loop was still running: the Qt event loop will
        delete those objects as soon as the new nested event loop starts.

        **Note:** It is safe to call this function more than once; when the
        first deferred deletion event is delivered, any pending events for the
        object are removed from the event queue.

        **Note:** This function is **thread-safe** .

        **See also** **destroyed** () and **QPointer** .
        """
        ...

    def inherits(self, classname: str) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#inherits

        **bool QObject::inherits(const char * className ) const**

        Returns `true` if this object is an instance of a class that inherits
        **className** or a **QObject**  subclass that inherits **className** ;
        otherwise returns `false`.

        A class is considered to inherit itself.

        Example:

        **QTimer**  *timer = new **QTimer** ;         // QTimer inherits QObject
        timer->inherits("QTimer");          // returns true
        timer->inherits("QObject");         // returns true
        timer->inherits("QAbstractButton"); // returns false

            //
        QVBoxLayout inherits QObject and QLayoutItem
            **QVBoxLayout**
        *layout = new **QVBoxLayout** ;
            layout->inherits("QObject");
        // returns true
            layout->inherits("QLayoutItem");    // returns true
        (even though QLayoutItem is not a QObject)

        If you need to determine whether an object is an instance of a
        particular class for the purpose of casting it, consider using
        **qobject_cast** <Type \\*>(object) instead.

        **See also** **metaObject** () and **qobject_cast** ().
        """
        ...

    def parent(self) -> "QObject":
        """
        https://doc.qt.io/qt-6/qobject.html#parent

        **QObject *QObject::parent() const**

        Returns a pointer to the parent object.

        **See also** **setParent** () and **children** ().
        """
        ...

    def property(self, name: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qobject.html#property

        **QVariant QObject::property(const char * name ) const**

        Returns the value of the object's **name** property.

        If no such property exists, the returned variant is invalid.

        Information about all available properties is provided through the
        **metaObject** () and **dynamicPropertyNames** ().

        **See also** **setProperty** (), **QVariant::isValid** (),
        **metaObject** (), and **dynamicPropertyNames** ().
        """
        ...

    def setProperty(self, name: str, value: typing.Any) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#setProperty

        **bool QObject::setProperty(const char * name , const QVariant & value
        )**

        Sets the value of the object's **name** property to **value**.

        If the property is defined in the class using **Q_PROPERTY**  then true
        is returned on success and false otherwise. If the property is not
        defined using **Q_PROPERTY** , and therefore not listed in the meta-
        object, it is added as a dynamic property and false is returned.

        Information about all available properties is provided through the
        **metaObject** () and **dynamicPropertyNames** ().

        Dynamic properties can be queried again using **property** () and can be
        removed by setting the property value to an invalid **QVariant** .
        Changing the value of a dynamic property causes a
        **QDynamicPropertyChangeEvent**  to be sent to the object.

        **Note:** Dynamic properties starting with "_q_" are reserved for
        internal purposes.

        **See also** **property** (), **metaObject** (),
        **dynamicPropertyNames** (), and **QMetaProperty::write** ().
        """
        ...

    def dynamicPropertyNames(self) -> typing.List["QByteArray"]:
        """
        https://doc.qt.io/qt-6/qobject.html#dynamicPropertyNames

        **QList<QByteArray> QObject::dynamicPropertyNames() const**

        Returns the names of all properties that were dynamically added to the
        object using **setProperty** ().
        """
        ...

    def dumpObjectTree(self) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#dumpObjectTree

        **void QObject::dumpObjectTree() const**

        Dumps a tree of children to the debug output.

        **Note:** Before Qt 5.9, this function was not const.

        **See also** **dumpObjectInfo** ().
        """
        ...

    def dumpObjectInfo(self) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#dumpObjectInfo

        **void QObject::dumpObjectInfo() const**

        Dumps information about signal connections, etc. for this object to the
        debug output.

        **Note:** Before Qt 5.9, this function was not const.

        **See also** **dumpObjectTree** ().
        """
        ...

    def removeEventFilter(self, a0: "QObject") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#removeEventFilter

        **void QObject::removeEventFilter(QObject * obj )**

        Removes an event filter object **obj** from this object. The request is
        ignored if such an event filter has not been installed.

        All event filters for this object are automatically removed when this
        object is destroyed.

        It is always safe to remove an event filter, even during event filter
        activation (i.e. from the **eventFilter** () function).

        **See also** **installEventFilter** (), **eventFilter** (), and
        **event** ().
        """
        ...

    def installEventFilter(self, a0: "QObject") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#installEventFilter

        **void QObject::installEventFilter(QObject * filterObj )**

        Installs an event filter **filterObj** on this object. For example:

        monitoredObj->installEventFilter(filterObj);

        An event filter is an object that receives all events that are sent to
        this object. The filter can either stop the event or forward it to this
        object. The event filter **filterObj** receives events via its
        **eventFilter** () function. The **eventFilter** () function must return
        true if the event should be filtered, (i.e. stopped); otherwise it must
        return false.

        If multiple event filters are installed on a single object, the filter
        that was installed last is activated first.

        Here's a `KeyPressEater` class that eats the key presses of its
        monitored objects:

        class KeyPressEater : public **QObject**
            {
                Q_OBJECT
        ...

            protected:
                bool eventFilter(**QObject**  *obj,
        **QEvent**  *event) override;
            };

            bool
        KeyPressEater::eventFilter(**QObject**  *obj, **QEvent**  *event)
            {
        if (event->type() == **QEvent** ::KeyPress) {
                    **QKeyEvent**
        *keyEvent = static_cast<**QKeyEvent**  \\*>(event);
        **qDebug** ("Ate key press %d", keyEvent->key());
                    return
        true;
                } else {
                    // standard event processing
        return **QObject** ::eventFilter(obj, event);
                }
            }

        And here's how to install it on two widgets:

        KeyPressEater *keyPressEater = new KeyPressEater(this);
        **QPushButton**  *pushButton = new **QPushButton** (this);
        **QListView**  *listView = new **QListView** (this);
        pushButton->installEventFilter(keyPressEater);
        listView->installEventFilter(keyPressEater);

        The **QShortcut**  class, for example, uses this technique to intercept
        shortcut key presses.

        **Warning:** If you delete the receiver object in your **eventFilter**
        () function, be sure to return true. If you return false, Qt sends the
        event to the deleted object and the program will crash.

        Note that the filtering object must be in the same thread as this
        object. If **filterObj** is in a different thread, this function does
        nothing. If either **filterObj** or this object are moved to a different
        thread after calling this function, the event filter will not be called
        until both objects have the same thread affinity again (it is **not**
        removed).

        **See also** **removeEventFilter** (), **eventFilter** (), and **event**
        ().
        """
        ...

    def setParent(self, a0: "QObject") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#setParent

        **void QObject::setParent(QObject * parent )**

        Makes the object a child of **parent**.

        **See also** **parent** () and **children** ().
        """
        ...

    def children(self) -> typing.List["QObject"]:
        """
        https://doc.qt.io/qt-6/qobject.html#children

        **const QObjectList &QObject::children() const**

        Returns a list of child objects. The **QObjectList**  class is defined
        in the `<QObject>` header file as the following:

        typedef **QList** <**QObject** \\*> **QObjectList** ;

        The first child added is the **first**  object in the list and the last
        child added is the **last**  object in the list, i.e. new children are
        appended at the end.

        Note that the list order changes when **QWidget**  children are
        **raised**  or **lowered** . A widget that is raised becomes the last
        object in the list, and a widget that is lowered becomes the first
        object in the list.

        **See also** **findChild** (), **findChildren** (), **parent** (), and
        **setParent** ().
        """
        ...

    def killTimer(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#killTimer

        **void QObject::killTimer(int id )**

        Kills the timer with timer identifier, **id**.

        The timer identifier is returned by **startTimer** () when a timer event
        is started.

        **See also** **timerEvent** () and **startTimer** ().
        """
        ...

    def startTimer(self, interval: int, timerType: Qt.TimerType = ...) -> int:
        """
        https://doc.qt.io/qt-6/qobject.html#startTimer

        **int QObject::startTimer(int interval , Qt::TimerType timerType =
        Qt::CoarseTimer)**

        Starts a timer and returns a timer identifier, or returns zero if it
        could not start a timer.

        A timer event will occur every **interval** milliseconds until
        **killTimer** () is called. If **interval** is 0, then the timer event
        occurs once every time there are no more window system events to
        process.

        The virtual **timerEvent** () function is called with the
        **QTimerEvent**  event parameter class when a timer event occurs.
        Reimplement this function to get timer events.

        If multiple timers are running, the **QTimerEvent::timerId** () can be
        used to find out which timer was activated.

        Example:

        class MyObject : public **QObject**
            {
                Q_OBJECT
        public:
                MyObject(**QObject**  *parent = nullptr);
        protected:
                void timerEvent(**QTimerEvent**  *event) override;
        };

            MyObject::MyObject(**QObject**  *parent)
                :
        **QObject** (parent)
            {
                startTimer(50);     // 50-millisecond
        timer
                startTimer(1000);   // 1-second timer
        startTimer(60000);  // 1-minute timer

                using namespace
        std::chrono;
                startTimer(milliseconds(50));
        startTimer(seconds(1));
                startTimer(minutes(1));

                //
        since C++14 we can use std::chrono::duration literals, e.g.:
        startTimer(100ms);
                startTimer(5s);
                startTimer(2min);
        startTimer(1h);
            }

            void MyObject::timerEvent(**QTimerEvent**
        *event)
            {
                **qDebug** () << "Timer ID:" << event->timerId();
        }

        Note that **QTimer** 's accuracy depends on the underlying operating
        system and hardware. The **timerType** argument allows you to customize
        the accuracy of the timer. See **Qt::TimerType**  for information on the
        different timer types. Most platforms support an accuracy of 20
        milliseconds; some provide more. If Qt is unable to deliver the
        requested number of timer events, it will silently discard some.

        The **QTimer**  class provides a high-level programming interface with
        single-shot timers and timer signals instead of events. There is also a
        **QBasicTimer**  class that is more lightweight than **QTimer**  and
        less clumsy than using timer IDs directly.

        **See also** **timerEvent** (), **killTimer** (), and
        **QTimer::singleShot** ().
        """
        ...

    def moveToThread(self, thread: "QThread") -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#moveToThread

        **void QObject::moveToThread(QThread * targetThread )**

        Changes the thread affinity for this object and its children. The object
        cannot be moved if it has a parent. Event processing will continue in
        the **targetThread**.

        To move an object to the main thread, use **QApplication::instance** ()
        to retrieve a pointer to the current application, and then use
        **QApplication::thread** () to retrieve the thread in which the
        application lives. For example:

        myObject->moveToThread(**QApplication** ::instance()->thread());

        If **targetThread** is `nullptr`, all event processing for this object
        and its children stops, as they are no longer associated with any
        thread.

        Note that all active timers for the object will be reset. The timers are
        first stopped in the current thread and restarted (with the same
        interval) in the **targetThread**. As a result, constantly moving an
        object between threads can postpone timer events indefinitely.

        A **QEvent::ThreadChange**  event is sent to this object just before the
        thread affinity is changed. You can handle this event to perform any
        special processing. Note that any new events that are posted to this
        object will be handled in the **targetThread** , provided it is not
        `nullptr`: when it is `nullptr`, no event processing for this object or
        its children can happen, as they are no longer associated with any
        thread.

        **Warning:** This function is **not** thread-safe; the current thread
        must be same as the current thread affinity. In other words, this
        function can only "push" an object from the current thread to another
        thread, it cannot "pull" an object from any arbitrary thread to the
        current thread. There is one exception to this rule however: objects
        with no thread affinity can be "pulled" to the current thread.

        **See also** **thread** ().
        """
        ...

    def thread(self) -> "QThread":
        """
        https://doc.qt.io/qt-6/qobject.html#thread

        **QThread *QObject::thread() const**

        Returns the thread in which the object lives.

        **See also** **moveToThread** ().
        """
        ...

    def blockSignals(self, b: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#blockSignals

        **bool QObject::blockSignals(bool block )**

        If **block** is true, signals emitted by this object are blocked (i.e.,
        emitting a signal will not invoke anything connected to it). If
        **block** is false, no such blocking will occur.

        The return value is the previous value of **signalsBlocked** ().

        Note that the **destroyed** () signal will be emitted even if the
        signals for this object have been blocked.

        Signals emitted while being blocked are not buffered.

        **See also** **signalsBlocked** () and **QSignalBlocker** .
        """
        ...

    def signalsBlocked(self) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#signalsBlocked

        **bool QObject::signalsBlocked() const**

        Returns `true` if signals are blocked; otherwise returns `false`.

        Signals are not blocked by default.

        **See also** **blockSignals** () and **QSignalBlocker** .
        """
        ...

    def isWindowType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#isWindowType

        **bool QObject::isWindowType() const**

        Returns `true` if the object is a window; otherwise returns `false`.

        Calling this function is equivalent to calling `inherits("QWindow")`,
        except that it is much faster.
        """
        ...

    def isWidgetType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#isWidgetType

        **bool QObject::isWidgetType() const**

        Returns `true` if the object is a widget; otherwise returns `false`.

        Calling this function is equivalent to calling `inherits("QWidget")`,
        except that it is much faster.
        """
        ...

    def setObjectName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qobject.html#objectName-prop

        **[bindable] objectName : QString**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the name of this object

        You can find an object by name (and type) using **findChild** (). You
        can find a set of objects with **findChildren** ().

        **qDebug** ("MyClass::setPrecision(): (%s) invalid precision %f",
        **qPrintable** (objectName()), newPrecision);

        By default, this property contains an empty string.

        **See also** **metaObject** () and **QMetaObject::className** ().

        **Member Function Documentation**
        """
        ...

    def objectName(self) -> str:
        """
        https://doc.qt.io/qt-6/qobject.html#objectName-prop

        **[bindable] objectName : QString**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the name of this object

        You can find an object by name (and type) using **findChild** (). You
        can find a set of objects with **findChildren** ().

        **qDebug** ("MyClass::setPrecision(): (%s) invalid precision %f",
        **qPrintable** (objectName()), newPrecision);

        By default, this property contains an empty string.

        **See also** **metaObject** () and **QMetaObject::className** ().

        **Member Function Documentation**
        """
        ...

    @typing.overload
    def findChildren(
        self, type: type, name: str = ..., options: Qt.FindChildOption = ...
    ) -> typing.List["QObject"]:
        """
        https://doc.qt.io/qt-6/qobject.html#findChildren

        **template <typename T> QList<T> QObject::findChildren(const QString &
        name = QString(), Qt::FindChildOptions options =
        Qt::FindChildrenRecursively) const**

        Returns all children of this object with the given **name** that can be
        cast to type T, or an empty list if there are no such objects. Omitting
        the **name** argument causes all object names to be matched. The search
        is performed recursively, unless **options** specifies the option
        FindDirectChildrenOnly.

        The following example shows how to find a list of child `QWidget`s of
        the specified `parentWidget` named `widgetname`:

        **QList** <**QWidget**  \\*> widgets =
        parentWidget.findChildren<**QWidget**  \\*>("widgetname");

        This example returns all `QPushButton`s that are children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> allPButtons =
        parentWidget.findChildren<**QPushButton**  \\*>();

        This example returns all `QPushButton`s that are immediate children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> childButtons =
        parentWidget.findChildren<**QPushButton**  \\*>(**QString** (),
        Qt::FindDirectChildrenOnly);

        **See also** **findChild** ().
        """
        ...

    @typing.overload
    def findChildren(
        self, types: typing.Tuple, name: str = ..., options: Qt.FindChildOption = ...
    ) -> typing.List["QObject"]:
        """
        https://doc.qt.io/qt-6/qobject.html#findChildren-1

        **[since 5.0] template <typename T> QList<T> QObject::findChildren(const
        QRegularExpression & re , Qt::FindChildOptions options =
        Qt::FindChildrenRecursively) const**

        This function overloads findChildren().

        Returns the children of this object that can be cast to type T and that
        have names matching the regular expression **re** , or an empty list if
        there are no such objects. The search is performed recursively, unless
        **options** specifies the option FindDirectChildrenOnly.

        This function was introduced in Qt 5.0.
        """
        ...

    @typing.overload
    def findChildren(
        self, type: type, re: "QRegularExpression", options: Qt.FindChildOption = ...
    ) -> typing.List["QObject"]:
        """
        https://doc.qt.io/qt-6/qobject.html#findChildren

        **template <typename T> QList<T> QObject::findChildren(const QString &
        name = QString(), Qt::FindChildOptions options =
        Qt::FindChildrenRecursively) const**

        Returns all children of this object with the given **name** that can be
        cast to type T, or an empty list if there are no such objects. Omitting
        the **name** argument causes all object names to be matched. The search
        is performed recursively, unless **options** specifies the option
        FindDirectChildrenOnly.

        The following example shows how to find a list of child `QWidget`s of
        the specified `parentWidget` named `widgetname`:

        **QList** <**QWidget**  \\*> widgets =
        parentWidget.findChildren<**QWidget**  \\*>("widgetname");

        This example returns all `QPushButton`s that are children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> allPButtons =
        parentWidget.findChildren<**QPushButton**  \\*>();

        This example returns all `QPushButton`s that are immediate children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> childButtons =
        parentWidget.findChildren<**QPushButton**  \\*>(**QString** (),
        Qt::FindDirectChildrenOnly);

        **See also** **findChild** ().
        """
        ...

    @typing.overload
    def findChildren(
        self,
        types: typing.Tuple,
        re: "QRegularExpression",
        options: Qt.FindChildOption = ...,
    ) -> typing.List["QObject"]:
        """
        https://doc.qt.io/qt-6/qobject.html#findChildren

        **template <typename T> QList<T> QObject::findChildren(const QString &
        name = QString(), Qt::FindChildOptions options =
        Qt::FindChildrenRecursively) const**

        Returns all children of this object with the given **name** that can be
        cast to type T, or an empty list if there are no such objects. Omitting
        the **name** argument causes all object names to be matched. The search
        is performed recursively, unless **options** specifies the option
        FindDirectChildrenOnly.

        The following example shows how to find a list of child `QWidget`s of
        the specified `parentWidget` named `widgetname`:

        **QList** <**QWidget**  \\*> widgets =
        parentWidget.findChildren<**QWidget**  \\*>("widgetname");

        This example returns all `QPushButton`s that are children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> allPButtons =
        parentWidget.findChildren<**QPushButton**  \\*>();

        This example returns all `QPushButton`s that are immediate children of
        `parentWidget`:

        **QList** <**QPushButton**  \\*> childButtons =
        parentWidget.findChildren<**QPushButton**  \\*>(**QString** (),
        Qt::FindDirectChildrenOnly);

        **See also** **findChild** ().
        """
        ...

    @typing.overload
    def findChild(
        self, type: type, name: str = ..., options: Qt.FindChildOption = ...
    ) -> "QObject":
        """
        https://doc.qt.io/qt-6/qobject.html#findChild

        **template <typename T> T QObject::findChild(const QString & name =
        QString(), Qt::FindChildOptions options = Qt::FindChildrenRecursively)
        const**

        Returns the child of this object that can be cast into type T and that
        is called **name** , or `nullptr` if there is no such object. Omitting
        the **name** argument causes all object names to be matched. The search
        is performed recursively, unless **options** specifies the option
        FindDirectChildrenOnly.

        If there is more than one child matching the search, the most direct
        ancestor is returned. If there are several direct ancestors, it is
        undefined which one will be returned. In that case, **findChildren** ()
        should be used.

        This example returns a child `QPushButton` of `parentWidget` named
        `"button1"`, even if the button isn't a direct child of the parent:

        **QPushButton**  *button = parentWidget->findChild<**QPushButton**
        \\*>("button1");

        This example returns a `QListWidget` child of `parentWidget`:

        **QListWidget**  *list = parentWidget->findChild<**QListWidget**  \\*>();

        This example returns a child `QPushButton` of `parentWidget` (its direct
        parent) named `"button1"`:

        **QPushButton**  *button = parentWidget->findChild<**QPushButton**
        \\*>("button1", Qt::FindDirectChildrenOnly);

        This example returns a `QListWidget` child of `parentWidget`, its direct
        parent:

        **QListWidget**  *list = parentWidget->findChild<**QListWidget**
        \\*>(**QString** (), Qt::FindDirectChildrenOnly);

        **See also** **findChildren** ().
        """
        ...

    @typing.overload
    def findChild(
        self, types: typing.Tuple, name: str = ..., options: Qt.FindChildOption = ...
    ) -> "QObject":
        """
        https://doc.qt.io/qt-6/qobject.html#findChild

        **template <typename T> T QObject::findChild(const QString & name =
        QString(), Qt::FindChildOptions options = Qt::FindChildrenRecursively)
        const**

        Returns the child of this object that can be cast into type T and that
        is called **name** , or `nullptr` if there is no such object. Omitting
        the **name** argument causes all object names to be matched. The search
        is performed recursively, unless **options** specifies the option
        FindDirectChildrenOnly.

        If there is more than one child matching the search, the most direct
        ancestor is returned. If there are several direct ancestors, it is
        undefined which one will be returned. In that case, **findChildren** ()
        should be used.

        This example returns a child `QPushButton` of `parentWidget` named
        `"button1"`, even if the button isn't a direct child of the parent:

        **QPushButton**  *button = parentWidget->findChild<**QPushButton**
        \\*>("button1");

        This example returns a `QListWidget` child of `parentWidget`:

        **QListWidget**  *list = parentWidget->findChild<**QListWidget**  \\*>();

        This example returns a child `QPushButton` of `parentWidget` (its direct
        parent) named `"button1"`:

        **QPushButton**  *button = parentWidget->findChild<**QPushButton**
        \\*>("button1", Qt::FindDirectChildrenOnly);

        This example returns a `QListWidget` child of `parentWidget`, its direct
        parent:

        **QListWidget**  *list = parentWidget->findChild<**QListWidget**
        \\*>(**QString** (), Qt::FindDirectChildrenOnly);

        **See also** **findChildren** ().
        """
        ...

    @staticmethod
    def tr(
        sourceText: str, disambiguation: typing.Optional[str] = ..., n: int = ...
    ) -> str:
        """
        https://doc.qt.io/qt-6/qobject.html#tr

        **[static] QString QObject::tr(const char * sourceText , const char *
        disambiguation = nullptr, int n = -1)**

        Returns a translated version of **sourceText** , optionally based on a
        **disambiguation** string and value of **n** for strings containing
        plurals; otherwise returns **QString::fromUtf8** ( **sourceText** ) if
        no appropriate translated string is available.

        Example:

        void MainWindow::createActions()
            {
                **QMenu**  *fileMenu =
        menuBar()->addMenu(tr("&File"));
                ...

        If the same **sourceText** is used in different roles within the same
        context, an additional identifying string may be passed in
        **disambiguation** (`nullptr` by default). In Qt 4.4 and earlier, this
        was the preferred way to pass comments to translators.

        Example:

        MyWindow::MyWindow()
            {
                **QLabel**  *senderLabel = new
        **QLabel** (tr("Name:"));
                **QLabel**  *recipientLabel = new
        **QLabel** (tr("Name:", "recipient"));
                ...

        See **Writing Source Code for Translation**  for a detailed description
        of Qt's translation mechanisms in general, and the **Disambiguation**
        section for information on disambiguation.

        **Warning:** This method is reentrant only if all translators are
        installed **before** calling this method. Installing or removing
        translators while performing translations is not supported. Doing so
        will probably result in crashes or other undesirable behavior.

        **See also** **QCoreApplication::translate** () and
        **Internationalization with Qt** .
        """
        ...

    def eventFilter(self, a0: "QObject", a1: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#eventFilter

        **[virtual] bool QObject::eventFilter(QObject * watched , QEvent * event
        )**

        Filters events if this object has been installed as an event filter for
        the **watched** object.

        In your reimplementation of this function, if you want to filter the
        **event** out, i.e. stop it being handled further, return true;
        otherwise return false.

        Example:

        class MainWindow : public **QMainWindow**
            {
            public:
        MainWindow();

            protected:
                bool eventFilter(**QObject**
        *obj, **QEvent**  *ev) override;

            private:
                **QTextEdit**
        *textEdit;
            };

            MainWindow::MainWindow()
            {
        textEdit = new **QTextEdit** ;
                setCentralWidget(textEdit);
        textEdit->installEventFilter(this);
            }

            bool
        MainWindow::eventFilter(**QObject**  *obj, **QEvent**  *event)
            {
        if (obj == textEdit) {
                    if (event->type() == **QEvent**
        ::KeyPress) {
                        **QKeyEvent**  *keyEvent =
        static_cast<**QKeyEvent** \\*>(event);
                        **qDebug** () <<
        "Ate key press" << keyEvent->key();
                        return true;
        } else {
                        return false;
                    }
                } else {
        // pass the event on to the parent class
                    return
        **QMainWindow** ::eventFilter(obj, event);
                }
            }

        Notice in the example above that unhandled events are passed to the base
        class's eventFilter() function, since the base class might have
        reimplemented eventFilter() for its own internal purposes.

        Some events, such as **QEvent::ShortcutOverride**  must be explicitly
        accepted (by calling **accept** () on them) in order to prevent
        propagation.

        **Warning:** If you delete the receiver object in this function, be sure
        to return true. Otherwise, Qt will forward the event to the deleted
        object and the program might crash.

        **See also** **installEventFilter** ().
        """
        ...

    def event(self, a0: "QEvent") -> bool:
        """
        https://doc.qt.io/qt-6/qobject.html#event

        **[virtual] bool QObject::event(QEvent * e )**

        This virtual function receives events to an object and should return
        true if the event **e** was recognized and processed.

        The event() function can be reimplemented to customize the behavior of
        an object.

        Make sure you call the parent event class implementation for all the
        events you did not handle.

        Example:

        class MyClass : public **QWidget**
            {
                Q_OBJECT
        public:
                MyClass(**QWidget**  *parent = nullptr);
        ~MyClass();

                bool event(**QEvent** * ev) override
                {
        if (ev->type() == **QEvent** ::PolishRequest) {
                        //
        overwrite handling of PolishRequest if any
                        doThings();
        return true;
                    } else  if (ev->type() == **QEvent** ::Show) {
        // complement handling of Show if any
                        doThings2();
        **QWidget** ::event(ev);
                        return true;
                    }
        // Make sure the rest of events are handled
                    return
        **QWidget** ::event(ev);
                }
            };

        **See also** **installEventFilter** (), **timerEvent** (),
        **QCoreApplication::sendEvent** (), and **QCoreApplication::postEvent**
        ().
        """
        ...

    def pyqtConfigure(self, a0: typing.Any) -> None:
        ...

    def metaObject(self) -> "QMetaObject":
        """
        https://doc.qt.io/qt-6/qobject.html#metaObject

        **[virtual] const QMetaObject *QObject::metaObject() const**

        Returns a pointer to the meta-object of this object.

        A meta-object contains information about a class that inherits
        **QObject** , e.g. class name, superclass name, properties, signals and
        slots. Every **QObject**  subclass that contains the **Q_OBJECT**  macro
        will have a meta-object.

        The meta-object information is required by the signal/slot connection
        mechanism and the property system. The **inherits** () function also
        makes use of the meta-object.

        If you have no pointer to an actual object instance but still want to
        access the meta-object of a class, you can use **staticMetaObject** .

        Example:

        **QObject**  *obj = new **QPushButton** ;
        obj->metaObject()->className();             // returns "QPushButton"
        **QPushButton** ::staticMetaObject.className();  // returns
        "QPushButton"

        **See also** **staticMetaObject** .
        """
        ...

    @property
    def destroyed(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qobject.html#destroyed

        **[signal] void QObject::destroyed(QObject * obj = nullptr)**

        This signal is emitted immediately before the object **obj** is
        destroyed, after any instances of **QPointer**  have been notified, and
        cannot be blocked.

        All the objects's children are destroyed immediately after this signal
        is emitted.

        **See also** **deleteLater** () and **QPointer** .
        """
        ...

    @property
    def objectNameChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qobject.html#objectNameChanged

        **[private signal] void QObject::objectNameChanged(const QString &
        objectName )**

        This signal is emitted after the object's name has been changed. The new
        object name is passed as **objectName**.

        **Note:** This is a private signal. It can be used in signal connections
        but cannot be emitted by the user.

        **Note:** Notifier signal for property **objectName** .

        **See also** **QObject::objectName** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGestureEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qgestureevent.html

    **Detailed Description**

    The QGestureEvent class contains a list of gestures, which can be obtained
    using the **gestures** () function.

    The gestures are either active or canceled. A list of those that are
    currently being executed can be obtained using the **activeGestures** ()
    function. A list of those which were previously active and have been
    canceled can be accessed using the **canceledGestures** () function. A
    gesture might be canceled if the current window loses focus, for example, or
    because of a timeout, or for other reasons.

    If the event handler does not accept the event by calling the generic
    **QEvent::accept** () function, all individual **QGesture**  object that
    were not accepted and in the **Qt::GestureStarted**  state will be
    propagated up the parent widget chain until a widget accepts them
    individually, by calling **QGestureEvent::accept** () for each of them, or
    an event filter consumes the event.

    **Further Reading**

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **See also** **QGesture** , **QGestureRecognizer** ,
    **QWidget::grabGesture** (), and **QGraphicsObject::grabGesture** ().
    """

    @typing.overload
    def __init__(self, gestures: typing.Iterable[QGesture]) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#QGestureEvent

        **QGestureEvent::QGestureEvent(const QList<QGesture *> & gestures )**

        Creates new QGestureEvent containing a list of **gestures**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QGestureEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#QGestureEvent

        **QGestureEvent::QGestureEvent(const QList<QGesture *> & gestures )**

        Creates new QGestureEvent containing a list of **gestures**.
        """
        ...

    def mapToGraphicsScene(self, gesturePoint: QtCore.QPointF) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#mapToGraphicsScene

        **QPointF QGestureEvent::mapToGraphicsScene(const QPointF & gesturePoint
        ) const**

        Returns the scene-local coordinates if the **gesturePoint** is inside a
        graphics view.

        This functional might be useful when the gesture event is delivered to a
        **QGraphicsObject**  to translate a point in screen coordinates to
        scene-local coordinates.

        **See also** **QPointF::isNull** ().
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#widget

        **QWidget *QGestureEvent::widget() const**

        Returns the widget on which the event occurred.
        """
        ...

    @typing.overload
    def ignore(self) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#ignore

        **void QGestureEvent::ignore(QGesture * gesture )**

        Clears the accept flag parameter of the given **gesture** object, the
        equivalent of calling **setAccepted** (gesture, false).

        Clearing the accept flag indicates that the event receiver does not want
        the gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::accept** ().
        """
        ...

    @typing.overload
    def ignore(self, a0: QGesture) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#ignore-1

        **void QGestureEvent::ignore(Qt::GestureType gestureType )**

        Clears the accept flag parameter of the given **gestureType** , the
        equivalent of calling **setAccepted** (gesture, false).

        Clearing the accept flag indicates that the event receiver does not want
        the gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::accept** ().
        """
        ...

    @typing.overload
    def ignore(self, a0: QtCore.Qt.GestureType) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#ignore

        **void QGestureEvent::ignore(QGesture * gesture )**

        Clears the accept flag parameter of the given **gesture** object, the
        equivalent of calling **setAccepted** (gesture, false).

        Clearing the accept flag indicates that the event receiver does not want
        the gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::accept** ().
        """
        ...

    @typing.overload
    def accept(self) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#accept

        **void QGestureEvent::accept(QGesture * gesture )**

        Sets the accept flag of the given **gesture** object, the equivalent of
        calling **setAccepted** (gesture, true).

        Setting the accept flag indicates that the event receiver wants the
        gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::ignore** ().
        """
        ...

    @typing.overload
    def accept(self, a0: QGesture) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#accept-1

        **void QGestureEvent::accept(Qt::GestureType gestureType )**

        Sets the accept flag of the given **gestureType** , the equivalent of
        calling **setAccepted** (gestureType, true).

        Setting the accept flag indicates that the event receiver wants the
        gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::ignore** ().
        """
        ...

    @typing.overload
    def accept(self, a0: QtCore.Qt.GestureType) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#accept

        **void QGestureEvent::accept(QGesture * gesture )**

        Sets the accept flag of the given **gesture** object, the equivalent of
        calling **setAccepted** (gesture, true).

        Setting the accept flag indicates that the event receiver wants the
        gesture. Unwanted gestures may be propagated to the parent widget.

        **See also** **QGestureEvent::ignore** ().
        """
        ...

    @typing.overload
    def isAccepted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#isAccepted

        **bool QGestureEvent::isAccepted(QGesture * gesture ) const**

        Returns `true` if the **gesture** is accepted; otherwise returns
        `false`.
        """
        ...

    @typing.overload
    def isAccepted(self, a0: QGesture) -> bool:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#isAccepted-1

        **bool QGestureEvent::isAccepted(Qt::GestureType gestureType ) const**

        Returns `true` if the gesture of type **gestureType** is accepted;
        otherwise returns `false`.
        """
        ...

    @typing.overload
    def isAccepted(self, a0: QtCore.Qt.GestureType) -> bool:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#isAccepted

        **bool QGestureEvent::isAccepted(QGesture * gesture ) const**

        Returns `true` if the **gesture** is accepted; otherwise returns
        `false`.
        """
        ...

    @typing.overload
    def setAccepted(self, accepted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#setAccepted

        **void QGestureEvent::setAccepted(QGesture * gesture , bool value )**

        Sets the accept flag of the given **gesture** object to the specified
        **value**.

        Setting the accept flag indicates that the event receiver wants the
        **gesture**. Unwanted gestures may be propagated to the parent widget.

        By default, gestures in events of type **QEvent::Gesture**  are
        accepted, and gestures in **QEvent::GestureOverride**  events are
        ignored.

        For convenience, the accept flag can also be set with **accept**
        (gesture), and cleared with **ignore** (gesture).

        **See also** **isAccepted** ().
        """
        ...

    @typing.overload
    def setAccepted(self, a0: QGesture, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#setAccepted-1

        **void QGestureEvent::setAccepted(Qt::GestureType gestureType , bool
        value )**

        Sets the accept flag of the given **gestureType** object to the
        specified **value**.

        Setting the accept flag indicates that the event receiver wants to
        receive gestures of the specified type, **gestureType**. Unwanted
        gestures may be propagated to the parent widget.

        By default, gestures in events of type **QEvent::Gesture**  are
        accepted, and gestures in **QEvent::GestureOverride**  events are
        ignored.

        For convenience, the accept flag can also be set with **accept**
        (gestureType), and cleared with **ignore** (gestureType).
        """
        ...

    @typing.overload
    def setAccepted(self, a0: QtCore.Qt.GestureType, a1: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#setAccepted

        **void QGestureEvent::setAccepted(QGesture * gesture , bool value )**

        Sets the accept flag of the given **gesture** object to the specified
        **value**.

        Setting the accept flag indicates that the event receiver wants the
        **gesture**. Unwanted gestures may be propagated to the parent widget.

        By default, gestures in events of type **QEvent::Gesture**  are
        accepted, and gestures in **QEvent::GestureOverride**  events are
        ignored.

        For convenience, the accept flag can also be set with **accept**
        (gesture), and cleared with **ignore** (gesture).

        **See also** **isAccepted** ().
        """
        ...

    def canceledGestures(self) -> typing.List[QGesture]:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#canceledGestures

        **QList<QGesture *> QGestureEvent::canceledGestures() const**

        Returns a list of canceled gestures.
        """
        ...

    def activeGestures(self) -> typing.List[QGesture]:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#activeGestures

        **QList<QGesture *> QGestureEvent::activeGestures() const**

        Returns a list of active (not canceled) gestures.
        """
        ...

    def gesture(self, type: QtCore.Qt.GestureType) -> QGesture:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#gesture

        **QGesture *QGestureEvent::gesture(Qt::GestureType type ) const**

        Returns a gesture object by **type**.
        """
        ...

    def gestures(self) -> typing.List[QGesture]:
        """
        https://doc.qt.io/qt-6/qgestureevent.html#gestures

        **QList<QGesture *> QGestureEvent::gestures() const**

        Returns all gestures that are delivered in the event.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore

PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]
QWIDGETSIZE_MAX: int = ...


def qDrawBorderPixmap(
    painter: QtGui.QPainter,
    target: QtCore.QRect,
    margins: QtCore.QMargins,
    pixmap: QtGui.QPixmap,
) -> None:
    ...


@typing.overload
def qDrawPlainRect(
    p: QtGui.QPainter,
    x: int,
    y: int,
    w: int,
    h: int,
    a5: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient],
    lineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawPlainRect(
    p: QtGui.QPainter,
    r: QtCore.QRect,
    a2: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient],
    lineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawWinPanel(
    p: QtGui.QPainter,
    x: int,
    y: int,
    w: int,
    h: int,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawWinPanel(
    p: QtGui.QPainter,
    r: QtCore.QRect,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawWinButton(
    p: QtGui.QPainter,
    x: int,
    y: int,
    w: int,
    h: int,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawWinButton(
    p: QtGui.QPainter,
    r: QtCore.QRect,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawShadePanel(
    p: QtGui.QPainter,
    x: int,
    y: int,
    w: int,
    h: int,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawShadePanel(
    p: QtGui.QPainter,
    r: QtCore.QRect,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawShadeRect(
    p: QtGui.QPainter,
    x: int,
    y: int,
    w: int,
    h: int,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    midLineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawShadeRect(
    p: QtGui.QPainter,
    r: QtCore.QRect,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    midLineWidth: int = ...,
    fill: typing.Optional[
        typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ]
    ] = ...,
) -> None:
    ...


@typing.overload
def qDrawShadeLine(
    p: QtGui.QPainter,
    x1: int,
    y1: int,
    x2: int,
    y2: int,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    midLineWidth: int = ...,
) -> None:
    ...


@typing.overload
def qDrawShadeLine(
    p: QtGui.QPainter,
    p1: QtCore.QPoint,
    p2: QtCore.QPoint,
    pal: QtGui.QPalette,
    sunken: bool = ...,
    lineWidth: int = ...,
    midLineWidth: int = ...,
) -> None:
    ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QListView(QAbstractItemView):
    """
    https://doc.qt.io/qt-6/qlistview.html

    **Detailed Description**

    ![](images/windows-listview.png)

    A QListView presents items stored in a model, either as a simple non-
    hierarchical list, or as a collection of icons. This class is used to
    provide lists and icon views that were previously provided by the `QListBox`
    and `QIconView` classes, but using the more flexible approach provided by
    Qt's model/view architecture.

    The QListView class is one of the **Model/View Classes**  and is part of
    Qt's **model/view framework** .

    This view does not display horizontal or vertical headers; to display a list
    of items with a horizontal header, use **QTreeView**  instead.

    QListView implements the interfaces defined by the **QAbstractItemView**
    class to allow it to display data provided by models derived from the
    **QAbstractItemModel**  class.

    Items in a list view can be displayed using one of two view modes: In
    **ListMode** , the items are displayed in the form of a simple list; in
    **IconMode** , the list view takes the form of an **icon view** in which the
    items are displayed with icons like files in a file manager. By default, the
    list view is in **ListMode** . To change the view mode, use the
    **setViewMode** () function, and to determine the current view mode, use
    **viewMode** ().

    Items in these views are laid out in the direction specified by the **flow**
    () of the list view. The items may be fixed in place, or allowed to move,
    depending on the view's **movement** () state.

    If the items in the model cannot be completely laid out in the direction of
    flow, they can be wrapped at the boundary of the view widget; this depends
    on **isWrapping** (). This property is useful when the items are being
    represented by an icon view.

    The **resizeMode** () and **layoutMode** () govern how and when the items
    are laid out. Items are spaced according to their **spacing** (), and can
    exist within a notional grid of size specified by **gridSize** (). The items
    can be rendered as large or small icons depending on their **iconSize** ().

    **Improving Performance**

    It is possible to give the view hints about the data it is handling in order
    to improve its performance when displaying large numbers of items. One
    approach that can be taken for views that are intended to display items with
    equal sizes is to set the **uniformItemSizes**  property to true.

    **See also** **View Classes** , **Item Views Puzzle Example** ,
    **QTreeView** , **QTableView** , and **QListWidget** .
    """

    class ViewMode(enum.Enum):
        ListMode: QListView = ...
        IconMode: QListView = ...

    class LayoutMode(enum.Enum):
        SinglePass: QListView = ...
        Batched: QListView = ...

    class ResizeMode(enum.Enum):
        Fixed: QListView = ...
        Adjust: QListView = ...

    class Flow(enum.Enum):
        LeftToRight: QListView = ...
        TopToBottom: QListView = ...

    class Movement(enum.Enum):
        Static: QListView = ...
        Free: QListView = ...
        Snap: QListView = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#QListView

        **QListView::QListView(QWidget * parent = nullptr)**

        Creates a new QListView with the given **parent** to view a model. Use
        **setModel** () to set the model.
        """
        ...

    def itemAlignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qlistview.html#itemAlignment-prop

        **[since 5.12] itemAlignment : Qt::Alignment**

        This property holds the alignment of each item in its cell

        This is only supported in **ListMode**  with **TopToBottom**  flow and
        with wrapping enabled. The default alignment is 0, which means that an
        item fills its cell entirely.

        This property was introduced in Qt 5.12.

        **Access functions:**

        Qt::Alignment **itemAlignment** () const
        void **setItemAlignment**
        (Qt::Alignment **alignment** )
        """
        ...

    def setItemAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#itemAlignment-prop

        **[since 5.12] itemAlignment : Qt::Alignment**

        This property holds the alignment of each item in its cell

        This is only supported in **ListMode**  with **TopToBottom**  flow and
        with wrapping enabled. The default alignment is 0, which means that an
        item fills its cell entirely.

        This property was introduced in Qt 5.12.

        **Access functions:**

        Qt::Alignment **itemAlignment** () const
        void **setItemAlignment**
        (Qt::Alignment **alignment** )
        """
        ...

    def initViewItemOption(self, option: "QStyleOptionViewItem") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#initViewItemOption

        **[override virtual protected] void
        QListView::initViewItemOption(QStyleOptionViewItem * option ) const**

        Reimplements:
        **QAbstractItemView::initViewItemOption(QStyleOptionViewItem *option)
        const** .
        """
        ...

    def currentChanged(
        self, current: QtCore.QModelIndex, previous: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#currentChanged

        **[override virtual protected] void QListView::currentChanged(const
        QModelIndex & current , const QModelIndex & previous )**

        Reimplements: **QAbstractItemView::currentChanged** (const QModelIndex
        &current, const QModelIndex &previous).
        """
        ...

    def selectionChanged(
        self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#selectionChanged

        **[override virtual protected] void QListView::selectionChanged(const
        QItemSelection & selected , const QItemSelection & deselected )**

        Reimplements: **QAbstractItemView::selectionChanged** (const
        QItemSelection &selected, const QItemSelection &deselected).
        """
        ...

    def isSelectionRectVisible(self) -> bool:
        ...

    def setSelectionRectVisible(self, show: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#selectionRectVisible-prop

        **selectionRectVisible : bool**

        if the selection rectangle should be visible

        If this property is `true` then the selection rectangle is visible;
        otherwise it will be hidden.

        **Note:** The selection rectangle will only be visible if the selection
        mode is in a mode where more than one item can be selected; i.e., it
        will not draw a selection rectangle if the selection mode is
        **QAbstractItemView::SingleSelection** .

        By default, this property is `false`.

        **Access functions:**

        bool **isSelectionRectVisible** () const
        void
        **setSelectionRectVisible** (bool **show** )
        """
        ...

    def wordWrap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `false` by default.

        Please note that even if wrapping is enabled, the cell will not be
        expanded to make room for the text. It will print ellipsis for text that
        cannot be shown, according to the view's **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def setWordWrap(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the item text word-wrapping policy

        If this property is `true` then the item text is wrapped where necessary
        at word-breaks; otherwise it is not wrapped at all. This property is
        `false` by default.

        Please note that even if wrapping is enabled, the cell will not be
        expanded to make room for the text. It will print ellipsis for text that
        cannot be shown, according to the view's **textElideMode** .

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **Member Function Documentation**
        """
        ...

    def batchSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistview.html#batchSize-prop

        **batchSize : int**

        This property holds the number of items laid out in each batch if
        **layoutMode**  is set to **Batched**

        The default value is 100.

        **Access functions:**

        int **batchSize** () const
        void **setBatchSize** (int **batchSize** )
        """
        ...

    def setBatchSize(self, batchSize: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#batchSize-prop

        **batchSize : int**

        This property holds the number of items laid out in each batch if
        **layoutMode**  is set to **Batched**

        The default value is 100.

        **Access functions:**

        int **batchSize** () const
        void **setBatchSize** (int **batchSize** )
        """
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlistview.html#viewportSizeHint

        **[override virtual protected, since 5.2] QSize
        QListView::viewportSizeHint() const**

        Reimplements: **QAbstractItemView::viewportSizeHint() const** .

        This function was introduced in Qt 5.2.
        """
        ...

    def isIndexHidden(self, index: QtCore.QModelIndex) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#isIndexHidden

        **[override virtual protected] bool QListView::isIndexHidden(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemView::isIndexHidden(const QModelIndex
        &index) const** .
        """
        ...

    def updateGeometries(self) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#updateGeometries

        **[override virtual protected] void QListView::updateGeometries()**

        Reimplements: **QAbstractItemView::updateGeometries** ().
        """
        ...

    def selectedIndexes(self) -> typing.List[QtCore.QModelIndex]:
        """
        https://doc.qt.io/qt-6/qlistview.html#selectedIndexes

        **[override virtual protected] QModelIndexList
        QListView::selectedIndexes() const**

        Reimplements: **QAbstractItemView::selectedIndexes() const** .
        """
        ...

    def visualRegionForSelection(
        self, selection: QtCore.QItemSelection
    ) -> QtGui.QRegion:
        """
        https://doc.qt.io/qt-6/qlistview.html#visualRegionForSelection

        **[override virtual protected] QRegion
        QListView::visualRegionForSelection(const QItemSelection & selection )
        const**

        Reimplements: **QAbstractItemView::visualRegionForSelection(const
        QItemSelection &selection) const** .

        Since 4.7, the returned region only contains rectangles intersecting (or
        included in) the viewport.
        """
        ...

    def setSelection(
        self, rect: QtCore.QRect, command: QtCore.QItemSelectionModel.SelectionFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#setSelection

        **[override virtual protected] void QListView::setSelection(const QRect
        & rect , QItemSelectionModel::SelectionFlags command )**

        Reimplements: **QAbstractItemView::setSelection** (const QRect &rect,
        QItemSelectionModel::SelectionFlags flags).
        """
        ...

    def setPositionForIndex(
        self, position: QtCore.QPoint, index: QtCore.QModelIndex
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#setPositionForIndex

        **[protected] void QListView::setPositionForIndex(const QPoint &
        position , const QModelIndex & index )**

        Sets the contents position of the item at **index** in the model to the
        given **position**. If the list view's movement mode is Static or its
        view mode is **ListView** , this function will have no effect.
        """
        ...

    def rectForIndex(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlistview.html#rectForIndex

        **[protected] QRect QListView::rectForIndex(const QModelIndex & index )
        const**

        Returns the rectangle of the item at position **index** in the model.
        The rectangle is in contents coordinates.

        **See also** **visualRect** ().
        """
        ...

    def moveCursor(
        self,
        cursorAction: QAbstractItemView.CursorAction,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qlistview.html#moveCursor

        **[override virtual protected] QModelIndex
        QListView::moveCursor(QAbstractItemView::CursorAction cursorAction ,
        Qt::KeyboardModifiers modifiers )**

        Reimplements: **QAbstractItemView::moveCursor**
        (QAbstractItemView::CursorAction cursorAction, Qt::KeyboardModifiers
        modifiers).
        """
        ...

    def verticalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistview.html#verticalOffset

        **[override virtual protected] int QListView::verticalOffset() const**

        Reimplements: **QAbstractItemView::verticalOffset() const** .
        """
        ...

    def horizontalOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistview.html#horizontalOffset

        **[override virtual protected] int QListView::horizontalOffset() const**

        Reimplements: **QAbstractItemView::horizontalOffset() const** .
        """
        ...

    def paintEvent(self, e: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#paintEvent

        **[override virtual protected] void QListView::paintEvent(QPaintEvent *
        e )**

        Reimplements: **QAbstractScrollArea::paintEvent** (QPaintEvent *event).
        """
        ...

    def startDrag(self, supportedActions: QtCore.Qt.DropAction) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#startDrag

        **[override virtual protected] void QListView::startDrag(Qt::DropActions
        supportedActions )**

        Reimplements: **QAbstractItemView::startDrag** (Qt::DropActions
        supportedActions).
        """
        ...

    def wheelEvent(self, e: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#wheelEvent

        **[override virtual protected] void QListView::wheelEvent(QWheelEvent *
        e )**

        Reimplements: **QAbstractScrollArea::wheelEvent** (QWheelEvent *e).
        """
        ...

    def dropEvent(self, e: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#dropEvent

        **[override virtual protected] void QListView::dropEvent(QDropEvent *
        event )**

        Reimplements: **QAbstractItemView::dropEvent** (QDropEvent *event).
        """
        ...

    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#dragLeaveEvent

        **[override virtual protected] void
        QListView::dragLeaveEvent(QDragLeaveEvent * e )**

        Reimplements: **QAbstractItemView::dragLeaveEvent** (QDragLeaveEvent
        *event).
        """
        ...

    def dragMoveEvent(self, e: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#dragMoveEvent

        **[override virtual protected] void
        QListView::dragMoveEvent(QDragMoveEvent * e )**

        Reimplements: **QAbstractItemView::dragMoveEvent** (QDragMoveEvent
        *event).
        """
        ...

    def resizeEvent(self, e: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#resizeEvent

        **[override virtual protected] void QListView::resizeEvent(QResizeEvent
        * e )**

        Reimplements: **QAbstractItemView::resizeEvent** (QResizeEvent *event).
        """
        ...

    def timerEvent(self, e: QtCore.QTimerEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#timerEvent

        **[override virtual protected] void QListView::timerEvent(QTimerEvent *
        e )**

        Reimplements: **QAbstractItemView::timerEvent** (QTimerEvent *event).
        """
        ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#mouseReleaseEvent

        **[override virtual protected] void
        QListView::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mouseReleaseEvent** (QMouseEvent
        *event).
        """
        ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#mouseMoveEvent

        **[override virtual protected] void
        QListView::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QAbstractItemView::mouseMoveEvent** (QMouseEvent
        *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#event

        **[override virtual protected] bool QListView::event(QEvent * e )**

        Reimplements: **QAbstractItemView::event** (QEvent *event).
        """
        ...

    def rowsAboutToBeRemoved(
        self, parent: QtCore.QModelIndex, start: int, end: int
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#rowsAboutToBeRemoved

        **[override virtual protected] void
        QListView::rowsAboutToBeRemoved(const QModelIndex & parent , int start ,
        int end )**

        Reimplements: **QAbstractItemView::rowsAboutToBeRemoved** (const
        QModelIndex &parent, int start, int end).
        """
        ...

    def rowsInserted(self, parent: QtCore.QModelIndex, start: int, end: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#rowsInserted

        **[override virtual protected] void QListView::rowsInserted(const
        QModelIndex & parent , int start , int end )**

        Reimplements: **QAbstractItemView::rowsInserted** (const QModelIndex
        &parent, int start, int end).
        """
        ...

    def dataChanged(
        self,
        topLeft: QtCore.QModelIndex,
        bottomRight: QtCore.QModelIndex,
        roles: typing.Iterable[int] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#dataChanged

        **[override virtual protected] void QListView::dataChanged(const
        QModelIndex & topLeft , const QModelIndex & bottomRight , const
        QList<int> & roles = QList<int>())**

        Reimplements: **QAbstractItemView::dataChanged** (const QModelIndex
        &topLeft, const QModelIndex &bottomRight, const QList<int> &roles).
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#scrollContentsBy

        **[override virtual protected] void QListView::scrollContentsBy(int dx ,
        int dy )**

        Reimplements: **QAbstractScrollArea::scrollContentsBy** (int dx, int
        dy).

        Scroll the view contents by **dx** and **dy**.
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#setRootIndex

        **[override virtual] void QListView::setRootIndex(const QModelIndex &
        index )**

        Reimplements: **QAbstractItemView::setRootIndex** (const QModelIndex
        &index).
        """
        ...

    def reset(self) -> None:
        ...

    def indexAt(self, p: QtCore.QPoint) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qlistview.html#indexAt

        **[override virtual] QModelIndex QListView::indexAt(const QPoint & p )
        const**

        Reimplements: **QAbstractItemView::indexAt(const QPoint &point) const**
        .
        """
        ...

    def scrollTo(
        self, index: QtCore.QModelIndex, hint: QAbstractItemView.ScrollHint = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#scrollTo

        **[override virtual] void QListView::scrollTo(const QModelIndex & index
        , QAbstractItemView::ScrollHint hint = EnsureVisible)**

        Reimplements: **QAbstractItemView::scrollTo** (const QModelIndex &index,
        QAbstractItemView::ScrollHint hint).
        """
        ...

    def visualRect(self, index: QtCore.QModelIndex) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlistview.html#visualRect

        **[override virtual] QRect QListView::visualRect(const QModelIndex &
        index ) const**

        Reimplements: **QAbstractItemView::visualRect(const QModelIndex &index)
        const** .
        """
        ...

    def uniformItemSizes(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#uniformItemSizes-prop

        **uniformItemSizes : bool**

        This property holds whether all items in the listview have the same size

        This property should only be set to true if it is guaranteed that all
        items in the view have the same size. This enables the view to do some
        optimizations for performance purposes.

        By default, this property is `false`.

        **Access functions:**

        bool **uniformItemSizes** () const
        void **setUniformItemSizes** (bool
        **enable** )
        """
        ...

    def setUniformItemSizes(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#uniformItemSizes-prop

        **uniformItemSizes : bool**

        This property holds whether all items in the listview have the same size

        This property should only be set to true if it is guaranteed that all
        items in the view have the same size. This enables the view to do some
        optimizations for performance purposes.

        By default, this property is `false`.

        **Access functions:**

        bool **uniformItemSizes** () const
        void **setUniformItemSizes** (bool
        **enable** )
        """
        ...

    def modelColumn(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistview.html#modelColumn-prop

        **modelColumn : int**

        This property holds the column in the model that is visible

        By default, this property contains 0, indicating that the first column
        in the model will be shown.

        **Access functions:**

        int **modelColumn** () const
        void **setModelColumn** (int **column** )
        """
        ...

    def setModelColumn(self, column: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#modelColumn-prop

        **modelColumn : int**

        This property holds the column in the model that is visible

        By default, this property contains 0, indicating that the first column
        in the model will be shown.

        **Access functions:**

        int **modelColumn** () const
        void **setModelColumn** (int **column** )
        """
        ...

    def setRowHidden(self, row: int, hide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#setRowHidden

        **void QListView::setRowHidden(int row , bool hide )**

        If **hide** is true, the given **row** will be hidden; otherwise the
        **row** will be shown.

        **See also** **isRowHidden** ().
        """
        ...

    def isRowHidden(self, row: int) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#isRowHidden

        **bool QListView::isRowHidden(int row ) const**

        Returns `true` if the **row** is hidden; otherwise returns `false`.
        """
        ...

    def clearPropertyFlags(self) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#clearPropertyFlags

        **void QListView::clearPropertyFlags()**

        Clears the **QListView** -specific property flags. See **viewMode** .

        Properties inherited from **QAbstractItemView**  are not covered by the
        property flags. Specifically, **dragEnabled**  and **acceptsDrops**  are
        computed by **QListView**  when calling **setMovement** () or
        **setViewMode** ().
        """
        ...

    def viewMode(self) -> "QListView.ViewMode":
        """
        https://doc.qt.io/qt-6/qlistview.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the view mode of the **QListView** .

        This property will change the other unset properties to conform with the
        set view mode. **QListView** -specific properties that have already been
        set will not be changed, unless **clearPropertyFlags** () has been
        called.

        Setting the view mode will enable or disable drag and drop based on the
        selected movement. For **ListMode** , the default movement is **Static**
        (drag and drop disabled); for **IconMode** , the default movement is
        **Free**  (drag and drop enabled).

        **Access functions:**

        QListView::ViewMode **viewMode** () const
        void **setViewMode**
        (QListView::ViewMode **mode** )

        **See also** **isWrapping** , **spacing** , **gridSize** , **flow** ,
        **movement** , and **resizeMode** .
        """
        ...

    def setViewMode(self, mode: "QListView.ViewMode") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#viewMode-prop

        **viewMode : ViewMode**

        This property holds the view mode of the **QListView** .

        This property will change the other unset properties to conform with the
        set view mode. **QListView** -specific properties that have already been
        set will not be changed, unless **clearPropertyFlags** () has been
        called.

        Setting the view mode will enable or disable drag and drop based on the
        selected movement. For **ListMode** , the default movement is **Static**
        (drag and drop disabled); for **IconMode** , the default movement is
        **Free**  (drag and drop enabled).

        **Access functions:**

        QListView::ViewMode **viewMode** () const
        void **setViewMode**
        (QListView::ViewMode **mode** )

        **See also** **isWrapping** , **spacing** , **gridSize** , **flow** ,
        **movement** , and **resizeMode** .
        """
        ...

    def gridSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlistview.html#gridSize-prop

        **gridSize : QSize**

        This property holds the size of the layout grid

        This property is the size of the grid in which the items are laid out.
        The default is an empty size which means that there is no grid and the
        layout is not done in a grid. Setting this property to a non-empty size
        switches on the grid layout. (When a grid layout is in force the
        **spacing**  property is ignored.)

        Setting this property when the view is visible will cause the items to
        be laid out again.

        **Access functions:**

        QSize **gridSize** () const
        void **setGridSize** (const QSize &
        **size** )

        **See also** **viewMode** .
        """
        ...

    def setGridSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#gridSize-prop

        **gridSize : QSize**

        This property holds the size of the layout grid

        This property is the size of the grid in which the items are laid out.
        The default is an empty size which means that there is no grid and the
        layout is not done in a grid. Setting this property to a non-empty size
        switches on the grid layout. (When a grid layout is in force the
        **spacing**  property is ignored.)

        Setting this property when the view is visible will cause the items to
        be laid out again.

        **Access functions:**

        QSize **gridSize** () const
        void **setGridSize** (const QSize &
        **size** )

        **See also** **viewMode** .
        """
        ...

    def spacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistview.html#spacing-prop

        **spacing : int**

        This property holds the space around the items in the layout

        This property is the size of the empty space that is padded around an
        item in the layout.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property contains a value of 0.

        **Access functions:**

        int **spacing** () const
        void **setSpacing** (int **space** )

        **See also** **viewMode** .
        """
        ...

    def setSpacing(self, space: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#spacing-prop

        **spacing : int**

        This property holds the space around the items in the layout

        This property is the size of the empty space that is padded around an
        item in the layout.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property contains a value of 0.

        **Access functions:**

        int **spacing** () const
        void **setSpacing** (int **space** )

        **See also** **viewMode** .
        """
        ...

    def layoutMode(self) -> "QListView.LayoutMode":
        """
        https://doc.qt.io/qt-6/qlistview.html#layoutMode-prop

        **layoutMode : LayoutMode**

        determines whether the layout of items should happen immediately or be
        delayed.

        This property holds the layout mode for the items. When the mode is
        **SinglePass**  (the default), the items are laid out all in one go.
        When the mode is **Batched** , the items are laid out in batches of
        **batchSize**  items, while processing events. This makes it possible to
        instantly view and interact with the visible items while the rest are
        being laid out.

        **Access functions:**

        QListView::LayoutMode **layoutMode** () const
        void **setLayoutMode**
        (QListView::LayoutMode **mode** )

        **See also** **viewMode** .
        """
        ...

    def setLayoutMode(self, mode: "QListView.LayoutMode") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#layoutMode-prop

        **layoutMode : LayoutMode**

        determines whether the layout of items should happen immediately or be
        delayed.

        This property holds the layout mode for the items. When the mode is
        **SinglePass**  (the default), the items are laid out all in one go.
        When the mode is **Batched** , the items are laid out in batches of
        **batchSize**  items, while processing events. This makes it possible to
        instantly view and interact with the visible items while the rest are
        being laid out.

        **Access functions:**

        QListView::LayoutMode **layoutMode** () const
        void **setLayoutMode**
        (QListView::LayoutMode **mode** )

        **See also** **viewMode** .
        """
        ...

    def resizeMode(self) -> "QListView.ResizeMode":
        """
        https://doc.qt.io/qt-6/qlistview.html#resizeMode-prop

        **resizeMode : ResizeMode**

        This property holds whether the items are laid out again when the view
        is resized.

        If this property is **Adjust** , the items will be laid out again when
        the view is resized. If the value is **Fixed** , the items will not be
        laid out when the view is resized.

        By default, this property is set to **Fixed** .

        **Access functions:**

        QListView::ResizeMode **resizeMode** () const
        void **setResizeMode**
        (QListView::ResizeMode **mode** )

        **See also** **movement** , **gridSize** , and **viewMode** .
        """
        ...

    def setResizeMode(self, mode: "QListView.ResizeMode") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#resizeMode-prop

        **resizeMode : ResizeMode**

        This property holds whether the items are laid out again when the view
        is resized.

        If this property is **Adjust** , the items will be laid out again when
        the view is resized. If the value is **Fixed** , the items will not be
        laid out when the view is resized.

        By default, this property is set to **Fixed** .

        **Access functions:**

        QListView::ResizeMode **resizeMode** () const
        void **setResizeMode**
        (QListView::ResizeMode **mode** )

        **See also** **movement** , **gridSize** , and **viewMode** .
        """
        ...

    def isWrapping(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlistview.html#isWrapping-prop

        **isWrapping : bool**

        This property holds whether the items layout should wrap.

        This property holds whether the layout should wrap when there is no more
        space in the visible area. The point at which the layout wraps depends
        on the **flow**  property.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property is `false`.

        **Access functions:**

        bool **isWrapping** () const
        void **setWrapping** (bool **enable** )

        **See also** **viewMode** .
        """
        ...

    def setWrapping(self, enable: bool) -> None:
        ...

    def flow(self) -> "QListView.Flow":
        """
        https://doc.qt.io/qt-6/qlistview.html#flow-prop

        **flow : Flow**

        This property holds which direction the items layout should flow.

        If this property is **LeftToRight** , the items will be laid out left to
        right. If the **isWrapping**  property is `true`, the layout will wrap
        when it reaches the right side of the visible area. If this property is
        **TopToBottom** , the items will be laid out from the top of the visible
        area, wrapping when it reaches the bottom.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property is set to **TopToBottom** .

        **Access functions:**

        QListView::Flow **flow** () const
        void **setFlow** (QListView::Flow
        **flow** )

        **See also** **viewMode** .
        """
        ...

    def setFlow(self, flow: "QListView.Flow") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#flow-prop

        **flow : Flow**

        This property holds which direction the items layout should flow.

        If this property is **LeftToRight** , the items will be laid out left to
        right. If the **isWrapping**  property is `true`, the layout will wrap
        when it reaches the right side of the visible area. If this property is
        **TopToBottom** , the items will be laid out from the top of the visible
        area, wrapping when it reaches the bottom.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property is set to **TopToBottom** .

        **Access functions:**

        QListView::Flow **flow** () const
        void **setFlow** (QListView::Flow
        **flow** )

        **See also** **viewMode** .
        """
        ...

    def movement(self) -> "QListView.Movement":
        """
        https://doc.qt.io/qt-6/qlistview.html#movement-prop

        **movement : Movement**

        This property holds whether the items can be moved freely, are snapped
        to a grid, or cannot be moved at all.

        This property determines how the user can move the items in the view.
        **Static**  means that the items can't be moved by the user. **Free**
        means that the user can drag and drop the items to any position in the
        view. **Snap**  means that the user can drag and drop the items, but
        only to the positions in a notional grid signified by the **gridSize**
        property.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property is set to **Static** .

        **Access functions:**

        QListView::Movement **movement** () const
        void **setMovement**
        (QListView::Movement **movement** )

        **See also** **gridSize** , **resizeMode** , and **viewMode** .
        """
        ...

    def setMovement(self, movement: "QListView.Movement") -> None:
        """
        https://doc.qt.io/qt-6/qlistview.html#movement-prop

        **movement : Movement**

        This property holds whether the items can be moved freely, are snapped
        to a grid, or cannot be moved at all.

        This property determines how the user can move the items in the view.
        **Static**  means that the items can't be moved by the user. **Free**
        means that the user can drag and drop the items to any position in the
        view. **Snap**  means that the user can drag and drop the items, but
        only to the positions in a notional grid signified by the **gridSize**
        property.

        Setting this property when the view is visible will cause the items to
        be laid out again.

        By default, this property is set to **Static** .

        **Access functions:**

        QListView::Movement **movement** () const
        void **setMovement**
        (QListView::Movement **movement** )

        **See also** **gridSize** , **resizeMode** , and **viewMode** .
        """
        ...

    @property
    def indexesMoved(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlistview.html#indexesMoved

        **[signal] void QListView::indexesMoved(const QModelIndexList & indexes
        )**

        This signal is emitted when the specified **indexes** are moved in the
        view.
        """
        ...
